@@ -173,7 +173,7 @@ class DetailedVoronoiContainer(MSONable):
 
                     min_dist = min([min_dist, distances[ridge_point2]])
                     for iii, sss in enumerate(self.structure):
-                        if neighbors[ridge_point2].is_periodic_image(sss, tolerance=1.0e-6):
+                        if neighbors[ridge_point2].is_periodic_image(sss, tolerance=1e-6):
                             idx = iii
                             break
                     results2.append(
@@ -463,7 +463,7 @@ class DetailedVoronoiContainer(MSONable):
             }
         else:
             raise ValueError(
-                f'Type {surface_calculation_options["type"]!r} for the surface calculation in DetailedVoronoiContainer '
+                f"Type {surface_calculation_options['type']!r} for the surface calculation in DetailedVoronoiContainer "
                 "is invalid"
             )
         max_dist = surface_calculation_options["distance_bounds"]["upper"] + 0.1
