@@ -6,7 +6,6 @@ solids, with or without an open element (e.g., flowing O2).
 from __future__ import annotations
 
 import json
-import os
 import warnings
 from typing import TYPE_CHECKING
 
@@ -18,6 +17,7 @@ from plotly.graph_objects import Figure, Scatter
 
 from pymatgen.analysis.phase_diagram import GrandPotentialPhaseDiagram, PhaseDiagram
 from pymatgen.analysis.reaction_calculator import Reaction
+from pymatgen.core import PKG_DIR
 from pymatgen.core.composition import Composition
 from pymatgen.util.due import Doi, due
 from pymatgen.util.plotting import pretty_plot
@@ -31,7 +31,7 @@ __maintainer__ = "Matthew McDermott"
 __email__ = "mcdermott@lbl.gov"
 __date__ = "Sep 1, 2021"
 
-with open(os.path.join(os.path.dirname(__file__), "..", "util", "plotly_interface_rxn_layouts.json")) as file:
+with open(f"{PKG_DIR}/util/plotly_interface_rxn_layouts.json", encoding="utf-8") as file:
     plotly_layouts = json.load(file)
 
 
@@ -93,8 +93,7 @@ class InterfacialReactivity(MSONable):
 
         if isinstance(pd, GrandPotentialPhaseDiagram) and not bypass_grand_warning:
             raise TypeError(
-                "Please use the GrandPotentialInterfacialReactivity "
-                "class for interfacial reactions with open elements!"
+                "Please use the GrandPotentialInterfacialReactivity class for interfacial reactions with open elements!"
             )
 
         self.c1 = c1
@@ -150,6 +149,7 @@ class InterfacialReactivity(MSONable):
         critical_comp = self.pd.get_critical_compositions(self.comp1, self.comp2)
         x_kink, energy_kink, react_kink, energy_per_rxt_formula = [], [], [], []
 
+        # TODO: perhaps a bad idea to use full equality to compare coords
         if (c1_coord == c2_coord).all():
             x_kink = [0, 1]
             energy_kink = [self._get_energy(x) for x in x_kink]
@@ -483,8 +483,10 @@ class InterfacialReactivity(MSONable):
 
         if not candidate:
             warnings.warn(
-                f"The reactant {composition.reduced_formula} has no matching entry with negative formation"
-                " energy, instead convex hull energy for this composition will be used for reaction energy calculation."
+                f"The reactant {composition.reduced_formula} has no matching entry "
+                "with negative formation energy, instead convex hull energy for "
+                "this composition will be used for reaction energy calculation.",
+                stacklevel=2,
             )
             return pd.get_hull_energy(composition)
         min_entry_energy = min(candidate)
@@ -527,7 +529,7 @@ class InterfacialReactivity(MSONable):
         return x * factor1 / ((1 - x) * factor2 + x * factor1)
 
     @classmethod
-    def get_chempot_correction(cls, element: str, temp: float, pres: float):
+    def get_chempot_correction(cls, element: str, temp: float, pres: float):  # codespell:ignore pres
         """Get the normalized correction term Δμ for chemical potential of a gas
         phase consisting of element at given temperature and pressure,
         referenced to that in the standard state (T_std = 298.15 K,
@@ -538,14 +540,15 @@ class InterfacialReactivity(MSONable):
         Args:
             element: The string representing the element.
             temp: The temperature of the gas phase in Kelvin.
-            pres: The pressure of the gas phase in Pa.
+            pres: The pressure of the gas phase in Pa.  # codespell:ignore pres
 
         Returns:
             The correction of chemical potential in eV/atom of the gas
             phase at given temperature and pressure.
         """
-        if element not in ["O", "N", "Cl", "F", "H"]:
-            warnings.warn(f"{element=} not one of valid options: ['O', 'N', 'Cl', 'F', 'H']")
+        valid_elements = {"O", "N", "Cl", "F", "H"}
+        if element not in valid_elements:
+            warnings.warn(f"{element=} not one of valid options: {valid_elements}", stacklevel=2)
             return 0
 
         std_temp = 298.15
@@ -560,7 +563,7 @@ class InterfacialReactivity(MSONable):
         cp_std = cp_dict[element]
         s_std = s_dict[element]
 
-        pv_correction = ideal_gas_const * temp * np.log(pres / std_pres)
+        pv_correction = ideal_gas_const * temp * np.log(pres / std_pres)  # codespell:ignore pres
         ts_correction = (
             -cp_std * (temp * np.log(temp) - std_temp * np.log(std_temp))
             + cp_std * (temp - std_temp) * (1 + np.log(std_temp))
