@@ -26,9 +26,10 @@ from pymatgen.transformations.standard_transformations import AutoOxiStateDecora
 from pymatgen.util.due import Doi, due
 
 if TYPE_CHECKING:
-    from typing import Any
+    from collections.abc import Sequence
+    from typing import Any, ClassVar
 
-    from numpy.typing import ArrayLike
+    from numpy.typing import ArrayLike, NDArray
 
 __author__ = "Matthew Horton"
 __copyright__ = "Copyright 2017, The Materials Project"
@@ -43,7 +44,7 @@ MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
 try:
     DEFAULT_MAGMOMS = loadfn(f"{MODULE_DIR}/default_magmoms.yaml")
 except (FileNotFoundError, MarkedYAMLError):
-    warnings.warn("Could not load default_magmoms.yaml, falling back to VASPIncarBase.yaml")
+    warnings.warn("Could not load default_magmoms.yaml, falling back to VASPIncarBase.yaml", stacklevel=2)
     DEFAULT_MAGMOMS = loadfn(f"{MODULE_DIR}/../../io/vasp/VASPIncarBase.yaml")["INCAR"]["MAGMOM"]
 
 
@@ -88,7 +89,7 @@ class CollinearMagneticStructureAnalyzer:
         threshold: float = 0,
         threshold_nonmag: float = 0.1,
         threshold_ordering: float = 1e-8,
-    ):
+    ) -> None:
         """
         If magnetic moments are not defined, moments will be
         taken either from default_magmoms.yaml (similar to the
@@ -148,7 +149,7 @@ class CollinearMagneticStructureAnalyzer:
 
         structure = structure.copy()
 
-        # check for disorder
+        # Check for disorder structure
         if not structure.is_ordered:
             raise NotImplementedError(
                 f"{type(self).__name__} not implemented for disordered structures, make ordered approximation first."
@@ -159,7 +160,7 @@ class CollinearMagneticStructureAnalyzer:
             try:
                 structure = trans.apply_transformation(structure)
             except ValueError:
-                warnings.warn(f"Could not assign valences for {structure.reduced_formula}")
+                warnings.warn(f"Could not assign valences for {structure.reduced_formula}", stacklevel=2)
 
         # Check if structure has magnetic moments
         # on site properties or species spin properties,
@@ -170,8 +171,7 @@ class CollinearMagneticStructureAnalyzer:
         has_spin = False
         for comp in structure.species_and_occu:
             for sp in comp:
-                if getattr(sp, "spin", False):
-                    has_spin = True
+                has_spin |= bool(getattr(sp, "spin", False))
 
         # perform input sanitation ...
         # rest of class will assume magnetic moments are stored on site properties:
@@ -187,7 +187,8 @@ class CollinearMagneticStructureAnalyzer:
             if None in structure.site_properties["magmom"]:
                 warnings.warn(
                     "Be careful with mixing types in your magmom site properties. "
-                    "Any 'None' magmoms have been replaced with zero."
+                    "Any 'None' magmoms have been replaced with zero.",
+                    stacklevel=2,
                 )
             magmoms = [m or 0 for m in structure.site_properties["magmom"]]
         elif has_spin:
@@ -208,7 +209,8 @@ class CollinearMagneticStructureAnalyzer:
                 "This class is not designed to be used with "
                 "non-collinear structures. If your structure is "
                 "only slightly non-collinear (e.g. canted) may still "
-                "give useful results, but use with caution."
+                "give useful results, but use with caution.",
+                stacklevel=2,
             )
 
         # this is for collinear structures only, make sure magmoms are all floats
@@ -284,8 +286,28 @@ class CollinearMagneticStructureAnalyzer:
         self.structure = structure
         self.threshold_ordering = threshold_ordering
 
+    def __str__(self) -> str:
+        """Sorts a Structure (by fractional coordinate), and
+        prints sites with magnetic information. This is
+        useful over Structure.__str__ because sites are in
+        a consistent order, which makes visual comparison between
+        two identical Structures with different magnetic orderings
+        easier.
+        """
+        frac_coords = self.structure.frac_coords
+        sorted_indices = np.lexsort((frac_coords[:, 2], frac_coords[:, 1], frac_coords[:, 0]))
+        struct = Structure.from_sites([self.structure[idx] for idx in sorted_indices])
+
+        # adapted from Structure.__repr__
+        outs = ["Structure Summary", repr(struct.lattice)]
+        outs.append("Magmoms Sites")
+        for site in struct:
+            prefix = f"{site.properties['magmom']:+.2f}   " if site.properties["magmom"] != 0 else "        "
+            outs.append(prefix + repr(site))
+        return "\n".join(outs)
+
     @staticmethod
-    def _round_magmoms(magmoms: ArrayLike, round_magmoms_mode: float) -> np.ndarray:
+    def _round_magmoms(magmoms: ArrayLike, round_magmoms_mode: float) -> NDArray:
         """If round_magmoms_mode is an integer, simply round to that number
         of decimal places, else if set to a float will try and round
         intelligently by grouping magmoms.
@@ -314,8 +336,8 @@ class CollinearMagneticStructureAnalyzer:
 
             except Exception as exc:
                 # TODO: typically a singular matrix warning, investigate this
-                warnings.warn("Failed to round magmoms intelligently, falling back to simple rounding.")
-                warnings.warn(str(exc))
+                warnings.warn("Failed to round magmoms intelligently, falling back to simple rounding.", stacklevel=2)
+                warnings.warn(str(exc), stacklevel=2)
 
             # and finally round roughly to the number of significant figures in our kde width
             n_decimals = len(str(round_magmoms_mode).split(".")[1]) + 1
@@ -333,7 +355,10 @@ class CollinearMagneticStructureAnalyzer:
 
         return structure
 
-    def get_structure_with_only_magnetic_atoms(self, make_primitive: bool = True) -> Structure:
+    def get_structure_with_only_magnetic_atoms(
+        self,
+        make_primitive: bool = True,
+    ) -> Structure:
         """Get a Structure with only magnetic atoms present.
 
         Args:
@@ -392,12 +417,12 @@ class CollinearMagneticStructureAnalyzer:
 
     @property
     def is_magnetic(self) -> bool:
-        """Convenience property, returns True if any non-zero magmoms present."""
+        """True if any non-zero magmoms present."""
         return any(map(abs, self.structure.site_properties["magmom"]))
 
     @property
-    def magmoms(self) -> np.ndarray:
-        """Convenience property, returns magmoms as a numpy array."""
+    def magmoms(self) -> NDArray:
+        """magmoms as a NumPy array."""
         return np.array(self.structure.site_properties["magmom"])
 
     @property
@@ -447,11 +472,15 @@ class CollinearMagneticStructureAnalyzer:
         """Number of magnetic sites present in structure."""
         return int(np.sum([abs(m) > 0 for m in self.magmoms]))
 
-    def number_of_unique_magnetic_sites(self, symprec: float = 1e-3, angle_tolerance: float = 5) -> int:
+    def number_of_unique_magnetic_sites(
+        self,
+        symprec: float = 1e-3,
+        angle_tolerance: float = 5,
+    ) -> int:
         """
         Args:
-            symprec: same as in SpacegroupAnalyzer (Default value = 1e-3)
-            angle_tolerance: same as in SpacegroupAnalyzer (Default value = 5).
+            symprec (float): same as in SpacegroupAnalyzer (Default value = 1e-3)
+            angle_tolerance (float): same as in SpacegroupAnalyzer (Default value = 5).
 
         Returns:
             int: Number of symmetrically-distinct magnetic sites present in structure.
@@ -484,7 +513,7 @@ class CollinearMagneticStructureAnalyzer:
                 (in which case a warning is issued).
         """
         if not self.is_collinear:
-            warnings.warn("Detecting ordering in non-collinear structures not yet implemented.")
+            warnings.warn("Detecting ordering in non-collinear structures not yet implemented.", stacklevel=2)
             return Ordering.Unknown
 
         if "magmom" not in self.structure.site_properties:
@@ -508,7 +537,11 @@ class CollinearMagneticStructureAnalyzer:
             return Ordering.AFM
         return Ordering.NM
 
-    def get_exchange_group_info(self, symprec: float = 1e-2, angle_tolerance: float = 5) -> tuple[str, int]:
+    def get_exchange_group_info(
+        self,
+        symprec: float = 1e-2,
+        angle_tolerance: float = 5,
+    ) -> tuple[str, int]:
         """Get the information on the symmetry of the Hamiltonian
         describing the exchange energy of the system, taking into
         account relative direction of magnetic moments but not their
@@ -520,11 +553,11 @@ class CollinearMagneticStructureAnalyzer:
         orderings within pymatgen.
 
         Args:
-            symprec: same as SpacegroupAnalyzer (Default value = 1e-2)
-            angle_tolerance: same as SpacegroupAnalyzer (Default value = 5)
+            symprec (float): same as SpacegroupAnalyzer (Default value = 1e-2)
+            angle_tolerance (float): same as SpacegroupAnalyzer (Default value = 5)
 
         Returns:
-            spacegroup_symbol, international_number
+            tuple[str, int]: spacegroup_symbol, international_number
         """
         structure = self.get_structure_with_spin()
 
@@ -561,26 +594,6 @@ class CollinearMagneticStructureAnalyzer:
 
         return cmag_analyzer.matches(b_positive) or cmag_analyzer.matches(analyzer)
 
-    def __str__(self):
-        """Sorts a Structure (by fractional coordinate), and
-        prints sites with magnetic information. This is
-        useful over Structure.__str__ because sites are in
-        a consistent order, which makes visual comparison between
-        two identical Structures with different magnetic orderings
-        easier.
-        """
-        frac_coords = self.structure.frac_coords
-        sorted_indices = np.lexsort((frac_coords[:, 2], frac_coords[:, 1], frac_coords[:, 0]))
-        struct = Structure.from_sites([self.structure[idx] for idx in sorted_indices])
-
-        # adapted from Structure.__repr__
-        outs = ["Structure Summary", repr(struct.lattice)]
-        outs.append("Magmoms Sites")
-        for site in struct:
-            prefix = f"{site.properties['magmom']:+.2f}   " if site.properties["magmom"] != 0 else "        "
-            outs.append(prefix + repr(site))
-        return "\n".join(outs)
-
 
 class MagneticStructureEnumerator:
     """Combines MagneticStructureAnalyzer and MagOrderingTransformation to
@@ -588,7 +601,7 @@ class MagneticStructureEnumerator:
     and produce a list of plausible magnetic orderings.
     """
 
-    available_strategies = (
+    available_strategies: ClassVar[tuple[str, ...]] = (
         "ferromagnetic",
         "antiferromagnetic",
         "ferrimagnetic_by_motif",
@@ -601,14 +614,14 @@ class MagneticStructureEnumerator:
         self,
         structure: Structure,
         default_magmoms: dict[str, float] | None = None,
-        strategies: list[str] | tuple[str, ...] = (
+        strategies: Sequence[str] = (
             "ferromagnetic",
             "antiferromagnetic",
         ),
         automatic: bool = True,
         truncate_by_symmetry: bool = True,
         transformation_kwargs: dict | None = None,
-    ):
+    ) -> None:
         """Generate different collinear magnetic orderings for a given input structure.
 
         If the input structure has magnetic moments defined, it
@@ -617,18 +630,18 @@ class MagneticStructureEnumerator:
         (this can be changed using default_magmoms kwarg).
 
         Args:
-            structure: input structure
-            default_magmoms: (optional, defaults provided) dict of
-                magnetic elements to their initial magnetic moments in μB, generally
-                these are chosen to be high-spin since they can relax to a low-spin
-                configuration during a DFT electronic configuration
-            strategies: different ordering strategies to use, choose from:
+            structure (Structure): input structure
+            default_magmoms (dict[str, float], optional): magnetic elements to their
+                initial magnetic moments in μB, generally these are chosen to be
+                high-spin since they can relax to a low-spin configuration during
+                a DFT electronic configuration
+            strategies (Sequence[str]): ordering strategies to use, choose from:
                 ferromagnetic, antiferromagnetic, antiferromagnetic_by_motif,
                 ferrimagnetic_by_motif and ferrimagnetic_by_species (here, "motif",
                 means to use a different ordering parameter for symmetry inequivalent
                 sites)
-            automatic: if True, will automatically choose sensible strategies
-            truncate_by_symmetry: if True, will remove very unsymmetrical
+            automatic (bool): if True, will automatically choose sensible strategies
+            truncate_by_symmetry (bool): if True, will remove very unsymmetrical
                 orderings that are likely physically implausible
             transformation_kwargs: keyword arguments to pass to
                 MagOrderingTransformation, to change automatic cell size limits, etc.
@@ -653,10 +666,7 @@ class MagneticStructureEnumerator:
         self.max_unique_sites = 8
 
         # kwargs to pass to transformation (ultimately to enumlib)
-        default_transformation_kwargs = {"check_ordered_symmetry": False, "timeout": 5}
-        transformation_kwargs = transformation_kwargs or {}
-        transformation_kwargs.update(default_transformation_kwargs)
-        self.transformation_kwargs = transformation_kwargs
+        self.transformation_kwargs = {"check_ordered_symmetry": False, "timeout": 5} | (transformation_kwargs or {})
 
         # our magnetically ordered structures will be
         # stored here once generated and also store which
@@ -728,7 +738,10 @@ class MagneticStructureEnumerator:
 
         return struct
 
-    def _generate_transformations(self, structure: Structure) -> dict[str, MagOrderingTransformation]:
+    def _generate_transformations(
+        self,
+        structure: Structure,
+    ) -> dict[str, MagOrderingTransformation]:
         """The central problem with trying to enumerate magnetic orderings is
         that we have to enumerate orderings that might plausibly be magnetic
         ground states, while not enumerating orderings that are physically
@@ -937,15 +950,13 @@ class MagneticStructureEnumerator:
         and self.ordered_structures_origins instance variables.
 
         Args:
-            sanitized_input_structure: A sanitized input structure
-            (_sanitize_input_structure)
+            sanitized_input_structure (Structure): A sanitized input structure
             transformations: A dict of transformations (values) and name of
-            enumeration strategy (key), the enumeration strategy name is just
-            for record keeping
-
+                enumeration strategy (key), the enumeration strategy name is just
+                for record keeping
 
         Returns:
-            list[Structures]
+            tuple[list[Structure], list[str]]
         """
         ordered_structures = self.ordered_structures
         ordered_structures_origins = self.ordered_structure_origins
@@ -1070,7 +1081,7 @@ def magnetic_deformation(structure_A: Structure, structure_B: Structure) -> Magn
     ferromagnetic structures.
 
     Adapted from Bocarsly et al. 2017,
-    doi: 10.1021/acs.chemmater.6b04729
+    DOI: 10.1021/acs.chemmater.6b04729
 
     Args:
         structure_A: Structure
