@@ -1,4 +1,9 @@
-"""Classes representing Element, Species (Element + oxidation state) and PeriodicTable."""
+"""Classes representing:
+- Element: Element in the periodic table.
+- Species: Element with optional oxidation state and spin.
+- DummySpecies: Non-traditional Elements/Species (vacancies/...).
+- ElementType: element types (metal/noble_gas/halogen/s_block/...).
+"""
 
 from __future__ import annotations
 
@@ -8,13 +13,12 @@ import json
 import re
 import warnings
 from collections import Counter
-from enum import Enum, unique
+from enum import Enum, EnumMeta, unique
 from itertools import combinations, product
 from pathlib import Path
 from typing import TYPE_CHECKING, overload
 
 import numpy as np
-from monty.dev import deprecated
 from monty.json import MSONable
 
 from pymatgen.core.units import SUPPORTED_UNIT_NAMES, FloatWithUnit, Ha_to_eV, Length, Mass, Unit
@@ -29,13 +33,14 @@ if TYPE_CHECKING:
 
     from pymatgen.util.typing import SpeciesLike
 
-# Load element data from JSON file
+# Load element data (periodic table) from JSON file
 with open(Path(__file__).absolute().parent / "periodic_table.json", encoding="utf-8") as ptable_json:
-    _pt_data = json.load(ptable_json)
+    _PT_DATA: dict = json.load(ptable_json)
 
-_pt_row_sizes = (2, 8, 8, 18, 18, 32, 32)
+_PT_ROW_SIZES: tuple[int, ...] = (2, 8, 8, 18, 18, 32, 32)
 
-_madelung = [
+# Madelung energy ordering rule (lower to higher energy)
+_MADELUNG: list[tuple[int, str]] = [
     (1, "s"),
     (2, "s"),
     (2, "p"),
@@ -61,88 +66,93 @@ _madelung = [
 @functools.total_ordering
 @unique
 class ElementBase(Enum):
-    """Element class defined without any enum values so it can be subclassed.
-
-    This class is needed to get nested (as|from)_dict to work properly. All emmet classes that had
-    Element classes required custom construction whereas this definition behaves more like dataclasses
-    so serialization is less troublesome. There were many times where objects in as_dict serialized
-    only when they were top level. See https://github.com/materialsproject/pymatgen/issues/2999.
-    """
+    """Element class defined without any enum values so it can be subclassed."""
 
     def __init__(self, symbol: SpeciesLike) -> None:
-        """Basic immutable element object with all relevant properties.
-
-        Only one instance of Element for each symbol is stored after creation,
-        ensuring that a particular element behaves like a singleton. For all
-        attributes, missing data (i.e., data for which is not available) is
-        represented by a None unless otherwise stated.
-
-        Args:
-            symbol (str): Element symbol, e.g. "H", "Fe"
+        """
+        This class provides a basic, immutable representation of an element, including
+        all relevant chemical and physical properties. It ensures that elements are
+        handled as singletons, reducing redundancy and improving efficiency. Missing
+        data is represented by `None` unless otherwise specified.
 
         Attributes:
-            Z (int): Atomic number.
-            symbol (str): Element symbol.
-            long_name (str): Long name for element. e.g. "Hydrogen".
-            A (int) : Atomic mass number (number of protons plus neutrons).
-            atomic_radius_calculated (float): Calculated atomic radius for the element. This is the empirical value.
-                Data is obtained from https://wikipedia.org/wiki/Atomic_radii_of_the_elements_(data_page).
-            van_der_waals_radius (float): Van der Waals radius for the element. This is the empirical value determined
-                from critical reviews of X-ray diffraction, gas kinetic collision cross-section, and other experimental
-                data by Bondi and later workers. The uncertainty in these values is on the order of 0.1 Å.
-                Data are obtained from "Atomic Radii of the Elements" in CRC Handbook of Chemistry and Physics,
-                91st Ed.; Haynes, W.M., Ed.; CRC Press: Boca Raton, FL, 2010.
-            mendeleev_no (int): Mendeleev number from definition given by Pettifor, D. G. (1984). A chemical scale
-                for crystal-structure maps. Solid State Communications, 51 (1), 31-34.
-            electrical_resistivity (float): Electrical resistivity.
-            velocity_of_sound (float): Velocity of sound.
-            reflectivity (float): Reflectivity.
-            refractive_index (float): Refractive index.
-            poissons_ratio (float): Poisson's ratio.
-            molar_volume (float): Molar volume.
-            electronic_structure (str): Electronic structure. e.g. The electronic structure for Fe is represented
-                as [Ar].3d6.4s2.
-            atomic_orbitals (dict): Atomic Orbitals. Energy of the atomic orbitals as a dict. e.g. The orbitals
-                energies in Hartree are represented as {'1s': -1.0, '2s': -0.1}. Data is obtained from
-                https://www.nist.gov/pml/data/atomic-reference-data-electronic-structure-calculations.
-                The LDA values for neutral atoms are used.
-            atomic_orbitals_eV (dict): Atomic Orbitals. Same as `atomic_orbitals` but energies are in eV.
-            thermal_conductivity (float): Thermal conductivity.
-            boiling_point (float): Boiling point.
-            melting_point (float): Melting point.
-            critical_temperature (float): Critical temperature.
-            superconduction_temperature (float): Superconduction temperature.
-            liquid_range (float): Liquid range.
-            bulk_modulus (float): Bulk modulus.
-            youngs_modulus (float): Young's modulus.
-            brinell_hardness (float): Brinell hardness.
-            rigidity_modulus (float): Rigidity modulus.
-            mineral_hardness (float): Mineral hardness.
-            vickers_hardness (float): Vicker's hardness.
-            density_of_solid (float): Density of solid phase.
-            coefficient_of_linear_thermal_expansion (float): Coefficient of linear thermal expansion.
-            ground_level (float): Ground level for element.
-            ionization_energies (list[Optional[float]]): List of ionization energies. First value is the first
-                ionization energy, second is the second ionization energy, etc. Note that this is zero-based indexing!
-                So Element.ionization_energies[0] refer to the 1st ionization energy. Values are from the NIST Atomic
-                Spectra Database. Missing values are None.
+            Z (int): Atomic number of the element.
+            symbol (str): Element symbol (e.g., "H", "Fe").
+            long_name (str): Full name of the element (e.g., "Hydrogen").
+            A (int, optional): Atomic mass number (sum of protons and neutrons).
+            atomic_radius_calculated (float, optional): Calculated atomic radius (Å).
+            van_der_waals_radius (float, optional): Van der Waals radius (Å).
+            mendeleev_no (int, optional): Mendeleev number based on crystal-structure maps.
+            electrical_resistivity (float, optional): Electrical resistivity (Ω·m).
+            velocity_of_sound (float, optional): Velocity of sound (m/s).
+            reflectivity (float, optional): Reflectivity (%).
+            refractive_index (float, optional): Refractive index.
+            poissons_ratio (float, optional): Poisson's ratio.
+            molar_volume (float, optional): Molar volume (cm³/mol).
+            electronic_structure (str): Electronic structure (e.g., "[Ar].3d6.4s2").
+            atomic_orbitals (dict): Orbital energies (Hartree units).
+            atomic_orbitals_eV (dict): Orbital energies in electron volts (eV).
+            thermal_conductivity (float, optional): Thermal conductivity (W/m·K).
+            boiling_point (float, optional): Boiling point (K).
+            melting_point (float, optional): Melting point (K).
+            critical_temperature (float, optional): Critical temperature (K).
+            superconduction_temperature (float, optional): Superconducting transition temperature (K).
+            liquid_range (float, optional): Temperature range for liquid phase (K).
+            bulk_modulus (float, optional): Bulk modulus (GPa).
+            youngs_modulus (float, optional): Young's modulus (GPa).
+            brinell_hardness (float, optional): Brinell hardness (MPa).
+            rigidity_modulus (float, optional): Rigidity modulus (GPa).
+            mineral_hardness (float, optional): Mohs hardness.
+            vickers_hardness (float, optional): Vickers hardness (MPa).
+            density_of_solid (float, optional): Density in solid phase (g/cm³).
+            coefficient_of_linear_thermal_expansion (float, optional): Thermal expansion coefficient (K⁻¹).
+            ground_level (float, optional): Ground energy level of the element.
+            ionization_energies (list[Optional[float]]): Ionization energies (kJ/mol), indexed from 0.
+
+        Examples:
+            Create an element instance and access its properties:
+                >>> hydrogen = Element("H")
+                >>> hydrogen.symbol
+                'H'
+                >>> hydrogen.Z
+                1
+                >>> hydrogen.electronic_structure
+                '1s1'
+
+            Access additional attributes such as atomic radius:
+                >>> hydrogen.atomic_radius_calculated
+                0.53
+
+        Notes:
+            - This class supports handling of isotopes by incorporating named isotopes
+            and their respective properties.
+            - Attributes are populated using a JSON file that stores data about all
+            known elements.
+            - Some attributes are calculated or derived based on predefined constants
+            and rules.
+
+        References:
+            - Atomic radius data: https://wikipedia.org/wiki/Atomic_radii_of_the_elements_(data_page)
+            - Van der Waals radius: CRC Handbook of Chemistry and Physics, 91st Ed.
+            - Mendeleev number: D. G. Pettifor, "A chemical scale for crystal-structure maps,"
+            Solid State Communications, 1984.
         """
         self.symbol = str(symbol)
-        data = _pt_data[symbol]
+        data = _PT_DATA[symbol]
 
         # Store key variables for quick access
         self.Z = data["Atomic no"]
 
         self._is_named_isotope = data.get("Is named isotope", False)
         if self._is_named_isotope:
-            for sym in _pt_data:
-                if _pt_data[sym]["Atomic no"] == self.Z and not _pt_data[sym].get("Is named isotope", False):
+            for sym, info in _PT_DATA.items():
+                if info["Atomic no"] == self.Z and not info.get("Is named isotope", False):
                     self.symbol = sym
                     break
             # For specified/named isotopes, treat the same as named element
             # (the most common isotope). Then we pad the data block with the
             # entries for the named element.
-            data = {**_pt_data[self.symbol], **data}
+            data = {**_PT_DATA[self.symbol], **data}
 
         at_r = data.get("Atomic radius", "no data")
         if str(at_r).startswith("no data"):
@@ -202,7 +212,7 @@ class ElementBase(Enum):
             key = item.capitalize().replace("_", " ")
             val = self._data.get(key)
             if val is None or str(val).startswith("no data"):
-                warnings.warn(f"No data available for {item} for {self.symbol}")
+                warnings.warn(f"No data available for {item} for {self.symbol}", stacklevel=2)
                 val = None
             elif isinstance(val, list | dict):
                 pass
@@ -241,7 +251,8 @@ class ElementBase(Enum):
                         and (match := re.findall(r"[\.\d]+", val))
                     ):
                         warnings.warn(
-                            f"Ambiguous values ({val}) for {item} of {self.symbol}. Returning first float value."
+                            f"Ambiguous values ({val}) for {item} of {self.symbol}. Returning first float value.",
+                            stacklevel=2,
                         )
                         return float(match[0])
             return val
@@ -288,7 +299,8 @@ class ElementBase(Enum):
             return X
         warnings.warn(
             f"No Pauling electronegativity for {self.symbol}. Setting to NaN. This has no physical meaning, "
-            "and is mainly done to avoid errors caused by the code expecting a float."
+            "and is mainly done to avoid errors caused by the code expecting a float.",
+            stacklevel=2,
         )
         return float("NaN")
 
@@ -337,7 +349,7 @@ class ElementBase(Enum):
     def ionization_energy(self) -> float | None:
         """First ionization energy of element."""
         if not self.ionization_energies:
-            warnings.warn(f"No data available for ionization_energy for {self.symbol}")
+            warnings.warn(f"No data available for ionization_energy for {self.symbol}", stacklevel=2)
             return None
         return self.ionization_energies[0]
 
@@ -441,33 +453,48 @@ class ElementBase(Enum):
 
     @property
     def full_electronic_structure(self) -> list[tuple[int, str, int]]:
-        """Full electronic structure as list of tuples, in order of increasing
+        """Full electronic structure in order of increasing
         energy level (according to the Madelung rule). Therefore, the final
         element in the list gives the electronic structure of the valence shell.
 
-        For example, the electronic structure for Fe is represented as:
-        [(1, "s", 2), (2, "s", 2), (2, "p", 6), (3, "s", 2), (3, "p", 6),
-        (4, "s", 2), (3, "d", 6)].
+        For example, the full electronic structure for Fe is:
+            [(1, "s", 2), (2, "s", 2), (2, "p", 6), (3, "s", 2), (3, "p", 6),
+            (4, "s", 2), (3, "d", 6)].
 
         References:
             Kramida, A., Ralchenko, Yu., Reader, J., and NIST ASD Team (2023). NIST
             Atomic Spectra Database (ver. 5.11). https://physics.nist.gov/asd [2024,
             June 3]. National Institute of Standards and Technology, Gaithersburg,
             MD. DOI: https://doi.org/10.18434/T4W30F
-        """
-        e_str = self.electronic_structure
 
-        def parse_orbital(orb_str):
+        Returns:
+            list[tuple[int, str, int]]: A list of tuples representing each subshell,
+            where each tuple contains:
+                - `n` (int): Principal quantum number.
+                - `orbital_type` (str): Orbital type (e.g., "s", "p", "d", "f").
+                - `electron_count` (int): Number of electrons in the subshell.
+        """
+        e_str: str = self.electronic_structure
+
+        def parse_orbital(orb_str: str) -> str | tuple[int, str, int]:
+            """Parse orbital information from split electron configuration string."""
+            # Parse valence subshell notation (e.g., "3d6" -> (3, "d", 6))
             if match := re.match(r"(\d+)([spdfg]+)(\d+)", orb_str):
                 return int(match[1]), match[2], int(match[3])
+
+            # Return core-electron configuration as-is (e.g. "[Ar]")
             return orb_str
 
-        data = [parse_orbital(s) for s in e_str.split(".")]
-        if data[0][0] == "[":
-            sym = data[0].replace("[", "").replace("]", "")
+        # Split e_str (e.g. for Fe "[Ar].3d6.4s2" into ["[Ar]", "3d6", "4s2"])
+        data: list = [parse_orbital(s) for s in e_str.split(".")]
+
+        # Fully expand core-electron configuration (replace noble gas notation string)
+        if isinstance(data[0], str):
+            sym: str = data[0].replace("[", "").replace("]", "")
             data = list(Element(sym).full_electronic_structure) + data[1:]
-        # sort the final electronic structure by increasing energy level
-        return sorted(data, key=lambda x: _madelung.index((x[0], x[1])))
+
+        # Sort the final electronic structure by increasing energy level
+        return sorted(data, key=lambda x: _MADELUNG.index((x[0], x[1])))
 
     @property
     def n_electrons(self) -> int:
@@ -552,7 +579,7 @@ class ElementBase(Enum):
         L_symbols = "SPDFGHIKLMNOQRTUVWXYZ"
 
         term_symbols = self.term_symbols
-        term_symbol_flat = {  # type: ignore[var-annotated]
+        term_symbol_flat: dict = {
             term: {
                 "multiplicity": int(term[0]),
                 "L": L_symbols.index(term[1]),
@@ -584,7 +611,7 @@ class ElementBase(Enum):
         Returns:
             Element with atomic number Z.
         """
-        for sym, data in _pt_data.items():
+        for sym, data in _PT_DATA.items():
             atomic_mass_num = data.get("Atomic mass no") if A else None
             if data["Atomic no"] == Z and atomic_mass_num == A:
                 return Element(sym)
@@ -605,7 +632,7 @@ class ElementBase(Enum):
         uk_to_us = {"aluminium": "aluminum", "caesium": "cesium"}
         name = uk_to_us.get(name.lower(), name)
 
-        for sym, data in _pt_data.items():
+        for sym, data in _PT_DATA.items():
             if data["Name"] == name.capitalize():
                 return Element(sym)
 
@@ -632,7 +659,7 @@ class ElementBase(Enum):
         Note:
             The 18 group number system is used, i.e. noble gases are group 18.
         """
-        for sym in _pt_data:
+        for sym in _PT_DATA:
             el = Element(sym)
             if 57 <= el.Z <= 71:
                 el_pseudo_row = 8
@@ -672,7 +699,7 @@ class ElementBase(Enum):
             return 6
         if 89 <= z <= 103:
             return 7
-        for idx, size in enumerate(_pt_row_sizes, start=1):
+        for idx, size in enumerate(_PT_ROW_SIZES, start=1):
             total += size
             if total >= z:
                 return idx
@@ -747,19 +774,6 @@ class ElementBase(Enum):
         """
         return self.is_lanthanoid or self.is_actinoid or self.symbol in {"Sc", "Y"}
 
-    @property
-    @deprecated(
-        is_rare_earth,
-        message="is_rare_earth is corrected to include Y and Sc.",
-        deadline=(2025, 1, 1),
-    )
-    def is_rare_earth_metal(self) -> bool:
-        """True if element is a rare earth metal, Lanthanides (La) series and Actinides (Ac) series.
-
-        This property is Deprecated, and scheduled for removal after 2025-01-01.
-        """
-        return self.is_lanthanoid or self.is_actinoid
-
     @property
     def is_metal(self) -> bool:
         """True if is a metal."""
@@ -871,8 +885,20 @@ class ElementBase(Enum):
             print(" ".join(row_str))
 
 
-@functools.total_ordering
-class Element(ElementBase):
+class _ElementMeta(EnumMeta):
+    """Override Element to handle isotopes."""
+
+    def __iter__(cls):
+        """Skip named isotopes when iterating."""
+        return (elem for elem in super().__iter__() if not elem._is_named_isotope)
+
+    @property
+    def named_isotopes(cls):
+        """Get all named isotopes."""
+        return tuple(elem for elem in super().__iter__() if elem._is_named_isotope)
+
+
+class Element(ElementBase, metaclass=_ElementMeta):
     """Enum representing an element in the periodic table."""
 
     # This name = value convention is redundant and dumb, but unfortunately is
@@ -1151,33 +1177,45 @@ class Species(MSONable, Stringify):
     # robustness
     @property
     def full_electronic_structure(self) -> list[tuple[int, str, int]]:
-        """Full electronic structure as list of tuples, in order of increasing
+        """Full electronic structure in order of increasing
         energy level (according to the Madelung rule). Therefore, the final
         element in the list gives the electronic structure of the valence shell.
 
-        For example, the electronic structure for Fe+2 is represented as:
-        [(1, "s", 2), (2, "s", 2), (2, "p", 6), (3, "s", 2), (3, "p", 6),
-        (3, "d", 6)].
+        For example, the full electronic structure for Fe is:
+            [(1, "s", 2), (2, "s", 2), (2, "p", 6), (3, "s", 2), (3, "p", 6),
+            (4, "s", 2), (3, "d", 6)].
 
         References:
             Kramida, A., Ralchenko, Yu., Reader, J., and NIST ASD Team (2023). NIST
             Atomic Spectra Database (ver. 5.11). https://physics.nist.gov/asd [2024,
             June 3]. National Institute of Standards and Technology, Gaithersburg,
             MD. DOI: https://doi.org/10.18434/T4W30F
-        """
-        e_str = self.electronic_structure
 
-        def parse_orbital(orb_str):
+        Returns:
+            list[tuple[int, str, int]]: A list of tuples representing each subshell,
+            where each tuple contains:
+                - `n` (int): Principal quantum number.
+                - `orbital_type` (str): Orbital type (e.g., "s", "p", "d", "f").
+                - `electron_count` (int): Number of electrons in the subshell.
+        """
+        e_str: str = self.electronic_structure
+
+        def parse_orbital(orb_str: str) -> str | tuple[int, str, int]:
+            """Parse orbital information from split electron configuration string."""
+            # Parse valence subshell notation (e.g., "3d6" -> (3, "d", 6))
             if match := re.match(r"(\d+)([spdfg]+)(\d+)", orb_str):
                 return int(match[1]), match[2], int(match[3])
+
+            # Return core-electron configuration as-is (e.g. "[Ar]")
             return orb_str
 
-        data = [parse_orbital(s) for s in e_str.split(".")]
-        if data[0][0] == "[":
+        data: list = [parse_orbital(s) for s in e_str.split(".")]
+        if isinstance(data[0], str):
             sym = data[0].replace("[", "").replace("]", "")
             data = list(Element(sym).full_electronic_structure) + data[1:]
-        # sort the final electronic structure by increasing energy level
-        return sorted(data, key=lambda x: _madelung.index((x[0], x[1])))
+
+        # Sort the final electronic structure by increasing energy level
+        return sorted(data, key=lambda x: _MADELUNG.index((x[0], x[1])))
 
     # NOTE - copied exactly from Element. Refactoring / inheritance may improve
     # robustness
@@ -1222,12 +1260,12 @@ class Species(MSONable, Stringify):
             oxi_str = str(int(self._oxi_state))
             warn_msg = f"No default ionic radius for {self}."
             if ion_rad := dct.get("Ionic radii hs", {}).get(oxi_str):
-                warnings.warn(f"{warn_msg} Using hs data.")
+                warnings.warn(f"{warn_msg} Using hs data.", stacklevel=2)
                 return ion_rad
             if ion_rad := dct.get("Ionic radii ls", {}).get(oxi_str):
-                warnings.warn(f"{warn_msg} Using ls data.")
+                warnings.warn(f"{warn_msg} Using ls data.", stacklevel=2)
                 return ion_rad
-        warnings.warn(f"No ionic radius for {self}!")
+        warnings.warn(f"No ionic radius for {self}!", stacklevel=2)
         return None
 
     @classmethod
@@ -1334,7 +1372,8 @@ class Species(MSONable, Stringify):
             if key != spin:
                 warnings.warn(
                     f"Specified {spin=} not consistent with database spin of {key}. "
-                    "Only one spin data available, and that value is returned."
+                    "Only one spin data available, and that value is returned.",
+                    stacklevel=2,
                 )
         else:
             data = radii[spin]
@@ -1592,14 +1631,12 @@ class DummySpecies(Species):
         return cls(dct["element"], dct["oxidation_state"], spin=dct.get("spin"))
 
 
-@functools.total_ordering
 class Specie(Species):
     """This maps the historical grammatically inaccurate Specie to Species
     to maintain backwards compatibility.
     """
 
 
-@functools.total_ordering
 class DummySpecie(DummySpecies):
     """This maps the historical grammatically inaccurate DummySpecie to DummySpecies
     to maintain backwards compatibility.
@@ -1640,8 +1677,6 @@ def get_el_sp(obj: int | SpeciesLike) -> Element | Species | DummySpecies:
     """
     # If obj is already an Element or Species, return as is
     if isinstance(obj, Element | Species | DummySpecies):
-        if getattr(obj, "_is_named_isotope", None):
-            return Element(obj.name) if isinstance(obj, Element) else Species(str(obj))
         return obj
 
     # If obj is an integer, return the Element with atomic number obj
