@@ -130,7 +130,10 @@ class CorrectionCalculator:
 
             compound = self.calc_compounds.get(name)
             if not compound:
-                warnings.warn(f"Compound {name} is not found in provided computed entries and is excluded from the fit")
+                warnings.warn(
+                    f"Compound {name} is not found in provided computed entries and is excluded from the fit",
+                    stacklevel=2,
+                )
                 continue
 
             # filter out compounds with large uncertainties
@@ -139,14 +142,17 @@ class CorrectionCalculator:
                 allow = False
                 warnings.warn(
                     f"Compound {name} is excluded from the fit due to high experimental "
-                    f"uncertainty ({relative_uncertainty:.1%})"
+                    f"uncertainty ({relative_uncertainty:.1%})",
+                    stacklevel=2,
                 )
 
             # filter out compounds containing certain polyanions
             for anion in self.exclude_polyanions:
                 if anion in name or anion in cmpd_info["formula"]:
                     allow = False
-                    warnings.warn(f"Compound {name} contains the poly{anion=} and is excluded from the fit")
+                    warnings.warn(
+                        f"Compound {name} contains the poly{anion=} and is excluded from the fit", stacklevel=2
+                    )
                     break
 
             # filter out compounds that are unstable
@@ -157,7 +163,9 @@ class CorrectionCalculator:
                     raise ValueError("Missing e above hull data")
                 if eah > self.allow_unstable:
                     allow = False
-                    warnings.warn(f"Compound {name} is unstable and excluded from the fit (e_above_hull = {eah})")
+                    warnings.warn(
+                        f"Compound {name} is unstable and excluded from the fit (e_above_hull = {eah})", stacklevel=2
+                    )
 
             if allow:
                 comp = Composition(name)
@@ -443,5 +451,5 @@ class CorrectionCalculator:
         contents["Uncertainties"].yaml_set_start_comment(
             "Uncertainties corresponding to each energy correction (eV/atom)", indent=2
         )
-        with open(path, mode="w") as file:
+        with open(path, mode="w", encoding="utf-8") as file:
             yml.dump(contents, file)
