@@ -112,7 +112,7 @@ class Cp2kOutput:
         return self.data.get("global").get("Run_type")
 
     @property
-    def calculation_type(self):
+    def calculation_type(self) -> str:
         """The calculation type (what io.vasp.outputs calls run_type)."""
         LDA_TYPES = {
             "LDA",
@@ -122,11 +122,8 @@ class Cp2kOutput:
             "BECKE88_LR_ADIABATIC",
             "BECKE97",
         }
-
         GGA_TYPES = {"PBE", "PW92"}
-
         HYBRID_TYPES = {"BLYP", "B3LYP"}
-
         METAGGA_TYPES = {
             "TPSS": "TPSS",
             "RTPSS": "revTPSS",
@@ -139,36 +136,36 @@ class Cp2kOutput:
         }
 
         functional = self.data.get("dft", {}).get("functional", [None])
-        ip = self.data.get("dft", {}).get("hfx", {}).get("Interaction_Potential")
+        inter_pot = self.data.get("dft", {}).get("hfx", {}).get("Interaction_Potential")
         frac = self.data.get("dft", {}).get("hfx", {}).get("FRACTION")
 
         if len(functional) > 1:
-            rt = "Mixed: " + ", ".join(functional)
+            run_type = "Mixed: " + ", ".join(functional)
             functional = " ".join(functional)
-            if "HYP" in functional or (ip and frac) or (functional in HYBRID_TYPES):
-                rt = "Hybrid"
+            if "HYP" in functional or (inter_pot and frac) or (functional in HYBRID_TYPES):
+                run_type = "Hybrid"
         else:
             functional = functional[0]
 
             if functional is None:
-                rt = "None"
-            elif "HYP" in functional or (ip and frac) or (functional) in HYBRID_TYPES:
-                rt = "Hybrid"
+                run_type = "None"
+            elif "HYP" in functional or (inter_pot and frac) or (functional) in HYBRID_TYPES:
+                run_type = "Hybrid"
             elif "MGGA" in functional or functional in METAGGA_TYPES:
-                rt = "METAGGA"
+                run_type = "METAGGA"
             elif "GGA" in functional or functional in GGA_TYPES:
-                rt = "GGA"
+                run_type = "GGA"
             elif "LDA" in functional or functional in LDA_TYPES:
-                rt = "LDA"
+                run_type = "LDA"
             else:
-                rt = "Unknown"
+                run_type = "Unknown"
 
         if self.is_hubbard:
-            rt += "+U"
-        if self.data.get("dft").get("vdw"):
-            rt += "+VDW"
+            run_type += "+U"
+        if self.data.get("dft", {}).get("vdw"):
+            run_type += "+VDW"
 
-        return rt
+        return run_type
 
     @property
     def project_name(self) -> str:
@@ -330,7 +327,7 @@ class Cp2kOutput:
         )
 
         coord_table = []
-        with zopen(self.filename, mode="rt") as file:
+        with zopen(self.filename, mode="rt", encoding="utf-8") as file:
             while True:
                 line = file.readline()
                 if re.search(r"Atom\s+Kind\s+Element\s+X\s+Y\s+Z\s+Z\(eff\)\s+Mass", line):
@@ -431,10 +428,10 @@ class Cp2kOutput:
         if not all(self.data["scf_converged"]):
             warnings.warn(
                 "There is at least one unconverged SCF cycle in the provided CP2K calculation",
-                UserWarning,
+                stacklevel=2,
             )
         if any(self.data["geo_opt_not_converged"]):
-            warnings.warn("Geometry optimization did not converge", UserWarning)
+            warnings.warn("Geometry optimization did not converge", stacklevel=2)
 
     def parse_energies(self):
         """Get the total energy from a CP2K calculation. Presently, the energy reported in the
@@ -499,7 +496,7 @@ class Cp2kOutput:
                 r"(-?\d+\.\d+E?[-|\+]?\d+)\s+(-?\d+\.\d+E?[-|\+]?\d+).*$"
             )
             footer_pattern = r"^$"
-            d = self.read_table_pattern(
+            dct = self.read_table_pattern(
                 header_pattern=header_pattern,
                 row_pattern=row_pattern,
                 footer_pattern=footer_pattern,
@@ -509,12 +506,12 @@ class Cp2kOutput:
 
             def chunks(lst, n):
                 """Yield successive n-sized chunks from lst."""
-                for i in range(0, len(lst), n):
-                    if i % 2 == 0:
-                        yield lst[i : i + n]
+                for idx in range(0, len(lst), n):
+                    if idx % 2 == 0:
+                        yield lst[idx : idx + n]
 
-            if d:
-                self.data["stress_tensor"] = list(chunks(d[0], 3))
+            if dct:
+                self.data["stress_tensor"] = list(chunks(dct[0], 3))
 
     def parse_ionic_steps(self):
         """Parse the ionic step info. If already parsed, this will just assimilate."""
@@ -527,13 +524,13 @@ class Cp2kOutput:
         if not self.data.get("stress_tensor"):
             self.parse_stresses()
 
-        for i, (structure, energy) in enumerate(zip(self.structures, self.data.get("total_energy"), strict=False)):
+        for idx, (structure, energy) in enumerate(zip(self.structures, self.data.get("total_energy"), strict=False)):
             self.ionic_steps.append(
                 {
                     "structure": structure,
                     "E": energy,
-                    "forces": (self.data["forces"][i] if self.data.get("forces") else None),
-                    "stress_tensor": (self.data["stress_tensor"][i] if self.data.get("stress_tensor") else None),
+                    "forces": (self.data["forces"][idx] if self.data.get("forces") else None),
+                    "stress_tensor": (self.data["stress_tensor"][idx] if self.data.get("stress_tensor") else None),
                 }
             )
 
@@ -569,7 +566,7 @@ class Cp2kOutput:
             if os.path.isfile(os.path.join(self.dir, input_filename + ext)):
                 self.input = Cp2kInput.from_file(os.path.join(self.dir, input_filename + ext))
                 return
-        warnings.warn("Original input file not found. Some info may be lost.")
+        warnings.warn("Original input file not found. Some info may be lost.", stacklevel=2)
 
     def parse_global_params(self):
         """Parse the GLOBAL section parameters from CP2K output file into a dictionary."""
@@ -664,11 +661,11 @@ class Cp2kOutput:
         )
         self.data["QS"] = dict(self.data["QS"])
         tmp = {}
-        i = 1
+        idx = 1
         for k in list(self.data["QS"]):
             if "grid_level" in str(k) and "Number" not in str(k):
-                tmp[i] = self.data["QS"].pop(k)
-                i += 1
+                tmp[idx] = self.data["QS"].pop(k)
+                idx += 1
         self.data["QS"]["Multi_grid_cutoffs_[a.u.]"] = tmp
 
     def parse_overlap_condition(self):
@@ -714,7 +711,8 @@ class Cp2kOutput:
             ]
 
         warnings.warn(
-            "Input file lost. Reading cell params from summary at top of output. Precision errors may result."
+            "Input file lost. Reading cell params from summary at top of output. Precision errors may result.",
+            stacklevel=2,
         )
         cell_volume = re.compile(r"\s+CELL\|\sVolume.*\s(\d+\.\d+)")
         vectors = re.compile(r"\s+CELL\| Vector.*\s(-?\d+\.\d+)\s+(-?\d+\.\d+)\s+(-?\d+\.\d+)")
@@ -726,8 +724,8 @@ class Cp2kOutput:
             postprocess=float,
             reverse=False,
         )
-        i = iter(self.data["lattice"])
-        lattices = list(zip(i, i, i, strict=True))
+        iterator = iter(self.data["lattice"])
+        lattices = list(zip(iterator, iterator, iterator, strict=True))
         return lattices[0]
 
     def parse_atomic_kind_info(self):
@@ -791,7 +789,7 @@ class Cp2kOutput:
             except (TypeError, IndexError, ValueError):
                 atomic_kind_info[kind]["total_pseudopotential_energy"] = None
 
-        with zopen(self.filename, mode="rt") as file:
+        with zopen(self.filename, mode="rt", encoding="utf-8") as file:
             j = -1
             lines = file.readlines()
             for k, line in enumerate(lines):
@@ -1012,7 +1010,7 @@ class Cp2kOutput:
         eigenvalues = []
         efermi = []
 
-        with zopen(self.filename, mode="rt") as file:
+        with zopen(self.filename, mode="rt", encoding="utf-8") as file:
             lines = iter(file.readlines())
             for line in lines:
                 try:
@@ -1049,7 +1047,8 @@ class Cp2kOutput:
                         while True:
                             if "WARNING : did not converge" in line:
                                 warnings.warn(
-                                    "Convergence of eigenvalues for unoccupied subspace spin 1 did NOT converge"
+                                    "Convergence of eigenvalues for unoccupied subspace spin 1 did NOT converge",
+                                    stacklevel=2,
                                 )
                                 next(lines)
                                 next(lines)
@@ -1076,7 +1075,8 @@ class Cp2kOutput:
                             while True:
                                 if "WARNING : did not converge" in line:
                                     warnings.warn(
-                                        "Convergence of eigenvalues for unoccupied subspace spin 2 did NOT converge"
+                                        "Convergence of eigenvalues for unoccupied subspace spin 2 did NOT converge",
+                                        stacklevel=2,
                                     )
                                     next(lines)
                                     next(lines)
@@ -1108,7 +1108,7 @@ class Cp2kOutput:
                             "unoccupied": {Spin.up: None, Spin.down: None},
                         }
                     ]
-                    warnings.warn("Convergence of eigenvalues for one or more subspaces did NOT converge")
+                    warnings.warn("Convergence of eigenvalues for one or more subspaces did NOT converge", stacklevel=2)
 
         self.data["eigenvalues"] = eigenvalues
 
@@ -1320,10 +1320,16 @@ class Cp2kOutput:
         else:
             eigenvals = {Spin.up: bands_data.reshape((nbands, nkpts))}
 
-        occ = bands_data[:, 1][bands_data[:, -1] != 0.0]
+        # Filter out occupied and unoccupied states
+        occupied_mask = ~np.isclose(bands_data[:, -1], 0.0)
+        unoccupied_mask = np.isclose(bands_data[:, -1], 0.0)
+
+        occ = bands_data[:, 1][occupied_mask]
         homo = np.max(occ)
-        unocc = bands_data[:, 1][bands_data[:, -1] == 0.0]
+
+        unocc = bands_data[:, 1][unoccupied_mask]
         lumo = np.min(unocc)
+
         efermi = (lumo + homo) / 2
         self.efermi = efermi
 
@@ -1349,7 +1355,7 @@ class Cp2kOutput:
             else:
                 return None
 
-        with zopen(hyperfine_filename, mode="rt") as file:
+        with zopen(hyperfine_filename, mode="rt", encoding="utf-8") as file:
             lines = [line for line in file.read().split("\n") if line]
 
         hyperfine = [[] for _ in self.ionic_steps]
@@ -1370,7 +1376,7 @@ class Cp2kOutput:
             else:
                 return None
 
-        with zopen(gtensor_filename, mode="rt") as file:
+        with zopen(gtensor_filename, mode="rt", encoding="utf-8") as file:
             lines = [line for line in file.read().split("\n") if line]
 
         data = {}
@@ -1407,19 +1413,10 @@ class Cp2kOutput:
             else:
                 return None
 
-        with zopen(chi_filename, mode="rt") as file:
+        with zopen(chi_filename, mode="rt", encoding="utf-8") as file:
             lines = [line for line in file.read().split("\n") if line]
 
-        data = {}
-        data["chi_soft"] = []
-        data["chi_local"] = []
-        data["chi_total"] = []
-        data["chi_total_ppm_cgs"] = []
-        data["PV1"] = []
-        data["PV2"] = []
-        data["PV3"] = []
-        data["ISO"] = []
-        data["ANISO"] = []
+        data = {k: [] for k in "chi_soft chi_local chi_total chi_total_ppm_cgs PV1 PV2 PV3 ISO ANISO".split()}
         ionic = -1
         dat = None
         for line in lines:
@@ -1563,7 +1560,7 @@ class Cp2kOutput:
             row_pattern, or a dict in case that named capturing groups are defined by
             row_pattern.
         """
-        with zopen(self.filename, mode="rt") as file:
+        with zopen(self.filename, mode="rt", encoding="utf-8") as file:
             if strip:
                 lines = file.readlines()
                 text = "".join(
@@ -1700,7 +1697,7 @@ def parse_pdos(dos_file=None, spin_channel=None, total=False):
     """
     spin = Spin(spin_channel) if spin_channel else Spin.down if "BETA" in os.path.split(dos_file)[-1] else Spin.up
 
-    with zopen(dos_file, mode="rt") as file:
+    with zopen(dos_file, mode="rt", encoding="utf-8") as file:
         lines = file.readlines()
         kind = re.search(r"atomic kind\s(.*)\sat iter", lines[0]) or re.search(r"list\s(\d+)\s(.*)\sat iter", lines[0])
         kind = kind.groups()[0]
