@@ -21,8 +21,9 @@ from __future__ import annotations
 
 import itertools
 import os
+import typing
 import warnings
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 import numpy as np
 from ruamel.yaml import YAML
@@ -90,6 +91,7 @@ class DftSet(Cp2kInput):
         structure: Structure | Molecule,
         project_name: str = "CP2K",
         basis_and_potential: dict | None = None,
+        element_defaults: dict[str, dict[str, Any]] | None = None,
         xc_functionals: list | str | None = None,
         multiplicity: int = 0,
         ot: bool = True,
@@ -112,11 +114,16 @@ class DftSet(Cp2kInput):
         wfn_restart_file_name: str | None = None,
         kpoints: VaspKpoints | None = None,
         smearing: bool = False,
+        cell: dict[str, Any] | None = None,
         **kwargs,
     ) -> None:
         """
         Args:
             structure: Pymatgen structure or molecule object
+            basis_and_potential (dict): Basis set and pseudo-potential to use for each element.
+                See DftSet.get_basis_and_potential for allowed formats.
+            element_defaults (dict): Default settings such as initial magnetization for each
+                element. See DftSet.create_subsys for allowed formats.
             ot (bool): Whether or not to use orbital transformation method for matrix
                 diagonalization. OT is the flagship scf solver of CP2K, and will provide
                 speed-ups for this part of the calculation, but the system must have a band gap
@@ -177,11 +184,14 @@ class DftSet(Cp2kInput):
                 CP2K runs with gamma point only.
             smearing (bool): whether or not to activate smearing (should be done for systems
                 containing no (or a very small) band gap.
+            cell (dict[str, Any]): Keywords to add to the CELL section such as SYMMETRY.
+                See https://manual.cp2k.org/trunk/CP2K_INPUT/FORCE_EVAL/SUBSYS/CELL.html#CP2K_INPUT.FORCE_EVAL.SUBSYS.CELL
         """
         super().__init__(name="CP2K_INPUT", subsections={})
 
         self.structure = structure
         self.basis_and_potential = basis_and_potential or {}
+        self.element_defaults = element_defaults or {}
         self.project_name = project_name
         self.charge = int(structure.charge)
         if not multiplicity and isinstance(self.structure, Molecule):
@@ -209,6 +219,7 @@ class DftSet(Cp2kInput):
         self.kpoints = kpoints
         self.smearing = smearing
         self.kwargs = kwargs
+        self.cell = cell or {}
 
         # Enable force and energy evaluations (most calculations)
         self.insert(ForceEval())
@@ -226,7 +237,10 @@ class DftSet(Cp2kInput):
             ):
                 self.kpoints = None
             if ot and self.kpoints:
-                warnings.warn("As of 2022.1, kpoints not supported with OT. Defaulting to diagonalization")
+                warnings.warn(
+                    "As of 2022.1, kpoints not supported with OT. Defaulting to diagonalization",
+                    stacklevel=2,
+                )
                 ot = False
 
         # Build the global section
@@ -242,7 +256,7 @@ class DftSet(Cp2kInput):
             eps_default=eps_default,
             eps_pgf_orb=kwargs.get("eps_pgf_orb"),
         )
-        max_scf = max_scf or 20 if ot else 400  # If ot, max_scf is for inner loop
+        max_scf = (max_scf or 20) if ot else 400  # If ot, max_scf is for inner loop
         scf = Scf(eps_scf=eps_scf, max_scf=max_scf, subsections={})
 
         if ot:
@@ -280,13 +294,11 @@ class DftSet(Cp2kInput):
             scf.insert(mixing)
             scf["MAX_DIIS"] = Keyword("MAX_DIIS", 15)
 
-        # Get basis, potential, and xc info
+        # Get basis, potential, and XC info
         self.basis_and_potential = DftSet.get_basis_and_potential(self.structure, self.basis_and_potential)
-        self.basis_set_file_names = self.basis_and_potential.get("basis_filenames")
+        self.basis_set_file_names = self.basis_and_potential.get("basis_filenames", ())
         self.potential_file_name = self.basis_and_potential.get("potential_filename")
-        self.xc_functionals = DftSet.get_xc_functionals(
-            xc_functionals=xc_functionals
-        )  # kwargs.get("xc_functional", "PBE"))
+        self.xc_functionals = DftSet.get_xc_functionals(xc_functionals=xc_functionals)
 
         # create the subsys (structure)
         self.create_subsys(self.structure)
@@ -312,7 +324,7 @@ class DftSet(Cp2kInput):
             MULTIPLICITY=self.multiplicity,
             CHARGE=self.charge,
             uks=self.kwargs.get("spin_polarized", True),
-            basis_set_filenames=self.basis_set_file_names or [],
+            basis_set_filenames=self.basis_set_file_names,
             potential_filename=self.potential_file_name,
             subsections={"QS": qs, "SCF": scf, "MGRID": mgrid},
             wfn_restart_file_name=wfn_restart_file_name,
@@ -354,8 +366,13 @@ class DftSet(Cp2kInput):
         if kwargs.get("validate", True):
             self.validate()
 
+    @typing.no_type_check
     @staticmethod
-    def get_basis_and_potential(structure, basis_and_potential):
+    def get_basis_and_potential(
+        structure: Structure,
+        basis_and_potential: dict[str, dict[str, Any]],
+        cp2k_data_dir: str | None = None,
+    ) -> dict[str, dict[str, Any]]:
         """Get a dictionary of basis and potential info for constructing the input file.
 
         data in basis_and_potential argument can be specified in several ways:
@@ -395,28 +412,34 @@ class DftSet(Cp2kInput):
 
         Will raise an error if no basis/potential info can be found according to the input.
         """
-        data = {"basis_filenames": []}
-        functional = basis_and_potential.get("functional", SETTINGS.get("PMG_DEFAULT_CP2K_FUNCTIONAL"))
-        basis_type = basis_and_potential.get("basis_type", SETTINGS.get("PMG_DEFAULT_CP2K_BASIS_TYPE"))
+        cp2k_data_dir = cp2k_data_dir or os.getenv("CP2K_DATA_DIR") or SETTINGS.get("PMG_CP2K_DATA_DIR") or "."
+        data: dict[str, list[str]] = {"basis_filenames": []}
+        functional = basis_and_potential.get("functional", os.getenv("DEFAULT_CP2K_FUNCTIONAL")) or SETTINGS.get(
+            "PMG_DEFAULT_CP2K_FUNCTIONAL"
+        )
+        basis_type = basis_and_potential.get("basis_type", os.getenv("DEFAULT_CP2K_BASIS_TYPE")) or SETTINGS.get(
+            "PMG_DEFAULT_CP2K_BASIS_TYPE"
+        )
         potential_type = basis_and_potential.get(
             "potential_type",
-            SETTINGS.get("PMG_DEFAULT_POTENTIAL_TYPE", "Pseudopotential"),
+            os.getenv("DEFAULT_POTENTIAL_TYPE") or SETTINGS.get("PMG_DEFAULT_POTENTIAL_TYPE", "Pseudopotential"),
+        )
+        aux_basis_type = basis_and_potential.get(
+            "aux_basis_type",
+            os.getenv("DEFAULT_CP2K_AUX_BASIS_TYPE") or SETTINGS.get("PMG_DEFAULT_CP2K_AUX_BASIS_TYPE"),
         )
-        aux_basis_type = basis_and_potential.get("aux_basis_type", SETTINGS.get("PMG_DEFAULT_CP2K_AUX_BASIS_TYPE"))
 
         for el in structure.symbol_set:
-            possible_basis_sets = []
-            possible_potentials = []
-            basis, aux_basis, potential, DATA = None, None, None, None
+            possible_basis_sets, possible_potentials = [], []
+            DATA: dict[str, dict[str, Any]] = {}
+            basis, aux_basis, potential = None, None, None
             desired_basis, desired_aux_basis, desired_potential = None, None, None
-            have_element_file = os.path.isfile(os.path.join(SETTINGS.get("PMG_CP2K_DATA_DIR", "."), el))
+            elem_file_path = os.path.join(cp2k_data_dir, el)
+            have_element_file = os.path.isfile(elem_file_path)
 
             # Necessary if matching data to CP2K data files
             if have_element_file:
-                with open(
-                    os.path.join(SETTINGS.get("PMG_CP2K_DATA_DIR", "."), el),
-                    encoding="utf-8",
-                ) as file:
+                with open(elem_file_path, encoding="utf-8") as file:
                     yaml = YAML(typ="unsafe", pure=True)
                     DATA = yaml.load(file)
                     if not DATA.get("basis_sets"):
@@ -510,35 +533,40 @@ class DftSet(Cp2kInput):
                 reverse=True,
             )
 
-            def match_elecs(x):
-                for p in possible_potentials:
-                    if x.info.electrons == p.info.electrons:
-                        return p
+            def match_elecs(basis_set):
+                for potential in possible_potentials:
+                    if basis_set.info.electrons == potential.info.electrons:
+                        return potential
                 return None
 
-            for b in possible_basis_sets:
-                fb = match_elecs(b)
+            for basis_set in possible_basis_sets:
+                fb = match_elecs(basis_set)
                 if fb is not None:
-                    basis = b
+                    basis = basis_set
                     potential = fb
                     break
 
             if basis is None:
                 if not basis_and_potential.get(el, {}).get("basis"):
                     raise ValueError(f"No explicit basis found for {el} and matching has failed.")
-                warnings.warn(f"Unable to validate basis for {el}. Exact name provided will be put in input file.")
+                warnings.warn(
+                    f"Unable to validate basis for {el}. Exact name provided will be put in input file.",
+                    stacklevel=2,
+                )
                 basis = basis_and_potential[el].get("basis")
 
             if aux_basis is None and basis_and_potential.get(el, {}).get("aux_basis"):
                 warnings.warn(
-                    f"Unable to validate auxiliary basis for {el}. Exact name provided will be put in input file."
+                    f"Unable to validate auxiliary basis for {el}. Exact name provided will be put in input file.",
+                    stacklevel=2,
                 )
                 aux_basis = basis_and_potential[el].get("aux_basis")
 
             if potential is None:
                 if basis_and_potential.get(el, {}).get("potential"):
                     warnings.warn(
-                        f"Unable to validate potential for {el}. Exact name provided will be put in input file."
+                        f"Unable to validate potential for {el}. Exact name provided will be put in input file.",
+                        stacklevel=2,
                     )
                     potential = basis_and_potential.get(el, {}).get("potential")
                 else:
@@ -547,7 +575,8 @@ class DftSet(Cp2kInput):
             if hasattr(basis, "filename"):
                 data["basis_filenames"].append(basis.filename)
             pfn1 = data.get("potential_filename")
-            pfn2 = potential.filename
+            # use getattr to not raise an error if potential is str, not Potential object
+            pfn2 = getattr(potential, "filename", None)
             if pfn1 and pfn2 and pfn1 != pfn2:
                 raise ValueError(
                     "Provided potentials have more than one corresponding file."
@@ -556,6 +585,13 @@ class DftSet(Cp2kInput):
             data["potential_filename"] = pfn2
 
             data[el] = {"basis": basis, "aux_basis": aux_basis, "potential": potential}
+
+        # if potential_filename or basis_filenames not set by above code, use the global ones
+        if not data["potential_filename"]:
+            data["potential_filename"] = basis_and_potential.get("potential_filename")
+        if not data["basis_filenames"]:
+            data["basis_filenames"] = basis_and_potential.get("basis_filenames")
+
         return data
 
     @staticmethod
@@ -583,11 +619,11 @@ class DftSet(Cp2kInput):
         """Get XC functionals. If simplified names are provided in kwargs, they
         will be expanded into their corresponding X and C names.
         """
-        names = xc_functionals or SETTINGS.get("PMG_DEFAULT_CP2K_FUNCTIONAL")
+        names = xc_functionals or os.getenv("DEFAULT_CP2K_FUNCTIONAL") or SETTINGS.get("PMG_DEFAULT_CP2K_FUNCTIONAL")
         if not names:
             raise ValueError(
-                "No XC functional provided. Specify kwarg xc_functional or configure PMG_DEFAULT_FUNCTIONAL "
-                "in your .pmgrc.yaml file"
+                "No XC functional provided. Specify kwarg xc_functional, set env var DEFAULT_CP2K_FUNCTIONAL, or "
+                "configure PMG_DEFAULT_CP2K_FUNCTIONAL in your .pmgrc.yaml file"
             )
         if isinstance(names, str):
             names = [names]
@@ -677,7 +713,7 @@ class DftSet(Cp2kInput):
 
     def print_v_hartree(self, stride=(2, 2, 2)) -> None:
         """
-        Controls the printing of a cube file with eletrostatic potential generated by the
+        Controls the printing of a cube file with electrostatic potential generated by the
             total density (electrons+ions). It is valid only for QS with GPW formalism.
         Note that by convention the potential has opposite sign than the expected physical one.
         """
@@ -844,7 +880,8 @@ class DftSet(Cp2kInput):
             if max_cutoff_radius < cutoff_radius:
                 warnings.warn(
                     "Provided cutoff radius exceeds half the minimum"
-                    " distance between atoms. I hope you know what you're doing."
+                    " distance between atoms. I hope you know what you're doing.",
+                    stacklevel=2,
                 )
 
         ip_keywords: dict[str, Keyword] = {}
@@ -933,7 +970,8 @@ class DftSet(Cp2kInput):
         else:
             warnings.warn(
                 "Unknown hybrid functional. Using PBE base functional and overriding all "
-                "settings manually. Proceed with caution."
+                "settings manually. Proceed with caution.",
+                stacklevel=2,
             )
             pbe = PBE("ORIG", scale_c=gga_c_fraction, scale_x=gga_x_fraction)
             xc_functional = XCFunctional(functionals=[], subsections={"PBE": pbe})
@@ -1195,7 +1233,8 @@ class DftSet(Cp2kInput):
             warnings.warn(
                 "Reference functional will not be checked for validity. "
                 "Calculation will fail if the reference functional "
-                "does not exist in the dftd3 reference data"
+                "does not exist in the dftd3 reference data",
+                stacklevel=2,
             )
             keywords["PARAMETER_FILE_NAME"] = Keyword("PARAMETER_FILE_NAME", "dftd3.dat")
             keywords["REFERENCE_FUNCTIONAL"] = Keyword("REFERENCE_FUNCTIONAL", reference_functional)
@@ -1248,59 +1287,68 @@ class DftSet(Cp2kInput):
     def create_subsys(self, structure: Structure | Molecule) -> None:
         """Create the structure for the input."""
         subsys = Subsys()
+        cell_keywords = {key.upper(): Keyword(key.upper(), value) for key, value in self.cell.items()}
         if isinstance(structure, Structure):
-            subsys.insert(Cell(structure.lattice))
+            subsys.insert(Cell(structure.lattice, keywords=cell_keywords))
         else:
             x = max(*structure.cart_coords[:, 0], 1)
             y = max(*structure.cart_coords[:, 1], 1)
             z = max(*structure.cart_coords[:, 2], 1)
-            cell = Cell(lattice=Lattice([[10 * x, 0, 0], [0, 10 * y, 0], [0, 0, 10 * z]]))
-            cell.add(Keyword("PERIODIC", "NONE"))
+            cell = Cell(
+                lattice=Lattice([[10 * x, 0, 0], [0, 10 * y, 0], [0, 0, 10 * z]]),
+                keywords={"PERIODIC": Keyword("PERIODIC", "NONE")} | cell_keywords,
+            )
             subsys.insert(cell)
 
         # Insert atom kinds by identifying the unique sites (unique element and site properties)
         unique_kinds = get_unique_site_indices(structure)
-        for k, v in unique_kinds.items():
-            kind = k.split("_")[0]
-            kwargs = {}
+        for key, val in unique_kinds.items():
+            kind = key.split("_")[0]
+            kind_kwargs = {}
 
             _ox = (
-                self.structure.site_properties["oxi_state"][v[0]]
+                self.structure.site_properties["oxi_state"][val[0]]
                 if "oxi_state" in self.structure.site_properties
                 else 0
             )
-            _sp = self.structure.site_properties["spin"][v[0]] if "spin" in self.structure.site_properties else 0
+            _sp = self.structure.site_properties.get("spin", {val[0]: 0})[val[0]]
 
             bs = BrokenSymmetry.from_el(kind, _ox, _sp) if _ox else None
 
-            if "magmom" in self.structure.site_properties and not bs:
-                kwargs["magnetization"] = self.structure.site_properties["magmom"][v[0]]
+            # First try site properties
+            if (magmom := self.structure.site_properties.get("magmom")) and not bs:
+                kind_kwargs["magnetization"] = magmom[val[0]]
+            # Then try element defaults
+            elif kind_kwargs.get("magnetization") is None and (
+                magnetization := self.element_defaults.get(kind, {}).get("magnetization")
+            ):
+                kind_kwargs["magnetization"] = magnetization
 
-            if "ghost" in self.structure.site_properties:
-                kwargs["ghost"] = self.structure.site_properties["ghost"][v[0]]
+            if ghost := self.structure.site_properties.get("ghost"):
+                kind_kwargs["ghost"] = ghost[val[0]]
 
-            if "basis_set" in self.structure.site_properties:
-                basis_set = self.structure.site_properties["basis_set"][v[0]]
+            if basis_set := self.structure.site_properties.get("basis_set"):
+                basis_set = basis_set[val[0]]
             else:
                 basis_set = self.basis_and_potential[kind].get("basis")
 
-            if "potential" in self.structure.site_properties:
-                potential = self.structure.site_properties["potential"][v[0]]
+            if potential := self.structure.site_properties.get("potential"):
+                potential = potential[val[0]]
             else:
                 potential = self.basis_and_potential[kind].get("potential")
 
-            if "aux_basis" in self.structure.site_properties:
-                kwargs["aux_basis"] = self.structure.site_properties["aux_basis"][v[0]]
-            elif self.basis_and_potential[kind].get("aux_basis"):
-                kwargs["aux_basis"] = self.basis_and_potential[kind].get("aux_basis")
+            if aux_basis := self.structure.site_properties.get("aux_basis"):
+                kind_kwargs["aux_basis"] = aux_basis[val[0]]
+            elif aux_basis := self.basis_and_potential[kind].get("aux_basis"):
+                kind_kwargs["aux_basis"] = aux_basis
 
             _kind = Kind(
                 kind,
-                alias=k,
+                alias=key,
                 basis_set=basis_set,
                 potential=potential,
                 subsections={"BS": bs} if bs else {},
-                **kwargs,
+                **kind_kwargs,
             )
             if self.qs_method.upper() == "GAPW":
                 _kind.add(Keyword("RADIAL_GRID", 200))
