@@ -10,6 +10,7 @@ from __future__ import annotations
 
 import abc
 import logging
+import math
 import os
 import sys
 import warnings
@@ -103,10 +104,10 @@ class AbstractFeffInputSet(MSONable, abc.ABC):
         )
 
         for k, v in feff.items():
-            with open(os.path.join(output_dir, k), mode="w") as file:
+            with open(os.path.join(output_dir, k), mode="w", encoding="utf-8") as file:
                 file.write(str(v))
 
-        with open(f"{output_dir}/feff.inp", mode="w") as file:
+        with open(f"{output_dir}/feff.inp", mode="w", encoding="utf-8") as file:
             file.write(feff_input)
 
         # write the structure to CIF file
@@ -190,7 +191,7 @@ class FEFFDictSet(AbstractFeffInputSet):
                         "For Molecule objects with a net charge it is recommended to set one or more"
                         " ION tags in the input file by modifying user_tag_settings."
                         " Consult the FEFFDictSet docstring and the FEFF10 User Guide for more information.",
-                        UserWarning,
+                        stacklevel=2,
                     )
             else:
                 raise ValueError("'structure' argument must be a Structure or Molecule!")
@@ -250,7 +251,7 @@ class FEFFDictSet(AbstractFeffInputSet):
                 if not self.config_dict.get("KMESH"):
                     abc = self.structure.lattice.abc
                     mult = (self.nkpts * abc[0] * abc[1] * abc[2]) ** (1 / 3)
-                    self.config_dict["KMESH"] = [int(round(mult / length)) for length in abc]
+                    self.config_dict["KMESH"] = [round(mult / length) for length in abc]
             else:
                 logger.warning("Large system(>=14 atoms) or EXAFS calculation, removing K-space settings")
                 del self.config_dict["RECIPROCAL"]
@@ -314,14 +315,10 @@ class FEFFDictSet(AbstractFeffInputSet):
             distance_matrix = input_atoms.distance_matrix[0, :]
 
             # Get radius value
-            from math import ceil
-
-            radius = int(
-                ceil(
-                    input_atoms.get_distance(
-                        input_atoms.index(input_atoms[0]),
-                        input_atoms.index(input_atoms[-1]),
-                    )
+            radius = math.ceil(
+                input_atoms.get_distance(
+                    input_atoms.index(input_atoms[0]),
+                    input_atoms.index(input_atoms[-1]),
                 )
             )
 
