@@ -337,7 +337,10 @@ class Lobsterin(UserDict, MSONable):
         """
         # Read INCAR from file, which will be modified
         incar = Incar.from_file(incar_input)
-        warnings.warn("Please check your incar_input before using it. This method only changes three settings!")
+        warnings.warn(
+            "Please check your incar_input before using it. This method only changes three settings!",
+            stacklevel=2,
+        )
         if isym in {-1, 0}:
             incar["ISYM"] = isym
         else:
@@ -585,7 +588,7 @@ class Lobsterin(UserDict, MSONable):
         Returns:
             Lobsterin object
         """
-        with zopen(lobsterin, mode="rt") as file:
+        with zopen(lobsterin, mode="rt", encoding="utf-8") as file:
             lines = file.read().split("\n")
         if not lines:
             raise RuntimeError("lobsterin file contains no data.")
@@ -642,7 +645,7 @@ class Lobsterin(UserDict, MSONable):
                 raise ValueError("Lobster only works with PAW! Use different POTCARs")
 
         # Warning about a bug in LOBSTER-4.1.0
-        with zopen(POTCAR_input, mode="r") as file:
+        with zopen(POTCAR_input, mode="rt", encoding="utf-8") as file:
             data = file.read()
 
         if isinstance(data, bytes):
@@ -654,7 +657,8 @@ class Lobsterin(UserDict, MSONable):
                 "Lobster up to version 4.1.0."
                 "\n The keywords SHA256 and COPYR "
                 "cannot be handled by Lobster"
-                " \n and will lead to wrong results."
+                " \n and will lead to wrong results.",
+                stacklevel=2,
             )
 
         if potcar.functional != "PBE":
@@ -697,7 +701,8 @@ class Lobsterin(UserDict, MSONable):
             Lobsterin with standard settings
         """
         warnings.warn(
-            "Always check and test the provided basis functions. The spilling of your Lobster calculation might help"
+            "Always check and test the provided basis functions. The spilling of your Lobster calculation might help",
+            stacklevel=2,
         )
 
         if option not in {
