@@ -275,7 +275,7 @@ class PWInput:
         Returns:
             PWInput object
         """
-        with zopen(filename, mode="rt") as file:
+        with zopen(filename, mode="rt", encoding="utf-8") as file:
             return cls.from_str(file.read())
 
     @classmethod
