@@ -18,10 +18,11 @@ import numpy as np
 from monty.design_patterns import cached_class
 from monty.serialization import loadfn
 
+from pymatgen.core.operations import SymmOp
 from pymatgen.util.string import Stringify
 
 if TYPE_CHECKING:
-    from typing import ClassVar, Literal
+    from typing import ClassVar, Literal, TypeAlias
 
     from numpy.typing import ArrayLike
     from typing_extensions import Self
@@ -29,9 +30,9 @@ if TYPE_CHECKING:
     from pymatgen.core.lattice import Lattice
 
     # Don't import at runtime to avoid circular import
-    from pymatgen.core.operations import SymmOp  # noqa: TCH004
+    from pymatgen.core.operations import SymmOp  # noqa: TC004
 
-    CrystalSystem = Literal[
+    CrystalSystem: TypeAlias = Literal[
         "cubic",
         "hexagonal",
         "monoclinic",
@@ -44,6 +45,24 @@ if TYPE_CHECKING:
 
 SYMM_DATA = loadfn(os.path.join(os.path.dirname(__file__), "symm_data.json"))
 
+PG_ABBREV_MAP = {
+    "2/m2/m2/m": "mmm",
+    "4/m2/m2/m": "4/mmm",
+    "-32/m": "-3m",
+    "6/m2/m2/m": "6/mmm",
+    "2/m-3": "m-3",
+    "4/m-32/m": "m-3m",
+}
+PG_SETTINGS_MAP = {  # only one setting per crystal class in SYMM_DATA database available right now
+    "m2m": "mm2",
+    "2mm": "mm2",
+    "-4m2": "-42m",
+    "-62m": "-6m2",
+    "312": "32",
+    "31m": "3m",
+    "-31m": "-3m",
+}
+
 
 class SymmetryGroup(Sequence, Stringify, ABC):
     """Abstract class representing a symmetry group."""
@@ -86,7 +105,11 @@ class SymmetryGroup(Sequence, Stringify, ABC):
         Returns:
             bool: True if this group is a subgroup of the supplied group.
         """
-        warnings.warn("This is not fully functional. Only trivial subsets are tested right now. ")
+        warnings.warn(
+            "This is not fully functional. Only trivial subsets are tested right now. "
+            "This will not work if the crystallographic directions of the two groups are different.",
+            stacklevel=2,
+        )
         return set(self.symmetry_ops).issubset(supergroup.symmetry_ops)
 
     def is_supergroup(self, subgroup: SymmetryGroup) -> bool:
@@ -98,7 +121,11 @@ class SymmetryGroup(Sequence, Stringify, ABC):
         Returns:
             bool: True if this group is a supergroup of the supplied group.
         """
-        warnings.warn("This is not fully functional. Only trivial subsets are tested right now. ")
+        warnings.warn(
+            "This is not fully functional. Only trivial subsets are tested right now. "
+            "This will not work if the crystallographic directions of the two groups are different.",
+            stacklevel=2,
+        )
         return set(subgroup.symmetry_ops).issubset(self.symmetry_ops)
 
     def to_latex_string(self) -> str:
@@ -125,16 +152,23 @@ class PointGroup(SymmetryGroup):
         Please note that only the 32 crystal classes are supported right now.
 
         Args:
-            int_symbol (str): International or Hermann-Mauguin Symbol.
+            int_symbol (str): International or Hermann-Mauguin Symbol. Please note that the PointGroup object
+            may have a different setting than specified in the int_symbol as only one setting per point group
+            is available right now.
         """
         from pymatgen.core.operations import SymmOp
 
+        int_symbol = int_symbol.replace(" ", "")
+        int_symbol = PG_ABBREV_MAP.get(int_symbol, int_symbol)
+        int_symbol = PG_SETTINGS_MAP.get(int_symbol, int_symbol)
+
         self.symbol = int_symbol
         self.generators = [
             SYMM_DATA["generator_matrices"][enc] for enc in SYMM_DATA["point_group_encoding"][int_symbol]
         ]
         self._symmetry_ops = {SymmOp.from_rotation_and_translation(m) for m in self._generate_full_symmetry_ops()}
         self.order = len(self._symmetry_ops)
+        self.crystal_system = SYMM_DATA["point_group_crystal_system_map"][int_symbol]
 
     @property
     def symmetry_ops(self) -> set[SymmOp]:
@@ -176,10 +210,50 @@ class PointGroup(SymmetryGroup):
                 orbit.append(pp)
         return orbit
 
+    def is_subgroup(self, supergroup: PointGroup) -> bool:
+        """True if this group is a subgroup of the supplied group.
+            Modification of SymmetryGroup method with a few more constraints.
+
+        Args:
+            supergroup (pointGroup): Supergroup to test.
+
+        Returns:
+            bool: True if this group is a subgroup of the supplied group.
+        """
+        possible_but_direction_differences = (
+            ["trigonal", "cubic"],
+            ["monoclinic", "tetragonal"],
+            ["monoclinic", "hexagonal"],
+            ["monoclinic", "trigonal"],
+            ["orthorhombic", "hexagonal"],
+            ["orthorhombic", "tetragonal"],
+        )
+        if [self.crystal_system, supergroup.crystal_system] in possible_but_direction_differences:
+            raise NotImplementedError
+        warnings.warn(
+            "This is not fully functional. Only trivial subsets are tested right now. "
+            "This will not work if the crystallographic directions of the two groups are different.",
+            stacklevel=2,
+        )
+        return set(self.symmetry_ops).issubset(supergroup.symmetry_ops)
+
+    def is_supergroup(self, subgroup: PointGroup) -> bool:
+        """True if this group is a subgroup of the supplied group.
+            Modification of SymmetryGroup method with a few more constraints.
+
+        Args:
+            subgroup (PointGroup): Subgroup to test.
+
+        Returns:
+            bool: True if this group is a supergroup of the supplied group.
+        """
+        return subgroup.is_subgroup(self)
+
     @classmethod
     def from_space_group(cls, sg_symbol: str) -> PointGroup:
         """Instantiate one of the 32 crystal classes from a space group symbol in
         Hermann Mauguin notation (int symbol or full symbol).
+        Please note that the axes of space group and crystal class may be different.
 
         Args:
             sg_symbol: space group symbol in Hermann Mauguin notation.
@@ -190,20 +264,6 @@ class PointGroup(SymmetryGroup):
         Returns:
             crystal class in Hermann-Mauguin notation.
         """
-        abbrev_map = {
-            "2/m2/m2/m": "mmm",
-            "4/m2/m2/m": "4/mmm",
-            "-32/m": "-3m",
-            "6/m2/m2/m": "6/mmm",
-            "2/m-3": "m-3",
-            "4/m-32/m": "m-3m",
-        }
-        non_standard_map = {
-            "m2m": "mm2",
-            "2mm": "mm2",
-            "-4m2": "-42m",  # technically not non-standard
-            "-62m": "-6m2",  # technically not non-standard
-        }
         symbol = re.sub(r" ", "", sg_symbol)
 
         symm_ops = loadfn(os.path.join(os.path.dirname(__file__), "symm_ops.json"))  # get short symbol if possible
@@ -223,8 +283,8 @@ class PointGroup(SymmetryGroup):
         symbol = symbol[1:]  # Remove centering
         symbol = symbol.translate(str.maketrans("abcden", "mmmmmm"))  # Remove translation from glide planes
         symbol = re.sub(r"_.", "", symbol)  # Remove translation from screw axes
-        symbol = abbrev_map.get(symbol, symbol)
-        symbol = non_standard_map.get(symbol, symbol)
+        symbol = PG_ABBREV_MAP.get(symbol, symbol)
+        symbol = PG_SETTINGS_MAP.get(symbol, symbol)
 
         if symbol not in SYMM_DATA["point_group_encoding"]:
             raise ValueError(f"Could not create a valid crystal class ({symbol}) from {sg_symbol=}")
@@ -320,7 +380,8 @@ class SpaceGroup(SymmetryGroup):
                     self.full_symbol = spg["hermann_mauguin_u"]
                     warnings.warn(
                         f"Full symbol not available, falling back to short Hermann Mauguin symbol "
-                        f"{self.symbol} instead"
+                        f"{self.symbol} instead",
+                        stacklevel=2,
                     )
                     self.point_group = spg["point_group"]
                 self.int_number = spg["number"]
@@ -565,7 +626,7 @@ class SpaceGroup(SymmetryGroup):
         if not isinstance(supergroup, SpaceGroup):
             return NotImplemented
 
-        if len(supergroup.symmetry_ops) < len(self.symmetry_ops):
+        if len(supergroup.symmetry_ops) < len(self.symmetry_ops) and supergroup.point_group != self.point_group:
             return False
 
         groups = [{supergroup.int_number}]
@@ -574,7 +635,10 @@ class SpaceGroup(SymmetryGroup):
         while True:
             new_sub_groups = set()
             for i in groups[-1]:
-                new_sub_groups.update([j for j in max_subgroups[i] if j not in all_groups])
+                if len(groups) == 1:
+                    new_sub_groups.update(list(max_subgroups[i]))
+                else:
+                    new_sub_groups.update([j for j in max_subgroups[i] if j not in all_groups])
             if self.int_number in new_sub_groups:
                 return True
 
