@@ -4,7 +4,8 @@ from __future__ import annotations
 
 import abc
 import itertools
-from math import ceil, cos, e, pi, sin, tan
+import math
+from math import cos, pi, sin
 from typing import TYPE_CHECKING
 from warnings import warn
 
@@ -102,7 +103,7 @@ class KPathBase(abc.ABC):
                 distance = np.linalg.norm(
                     self._rec_lattice.get_cartesian_coords(start) - self._rec_lattice.get_cartesian_coords(end)
                 )
-                nb = ceil(distance * line_density)
+                nb = math.ceil(distance * line_density)
                 if nb == 0:
                     continue
                 sym_point_labels.extend([k_path[path_step - 1]] + [""] * (nb - 1) + [k_path[path_step]])
@@ -151,7 +152,11 @@ class KPathSetyawanCurtarolo(KPathBase):
         """
         if "magmom" in structure.site_properties:
             warn(
-                "'magmom' entry found in site properties but will be ignored for the Setyawan and Curtarolo convention."
+                (
+                    "'magmom' entry found in site properties but will be ignored "
+                    "for the Setyawan and Curtarolo convention."
+                ),
+                stacklevel=2,
             )
 
         super().__init__(structure, symprec=symprec, angle_tolerance=angle_tolerance, atol=atol)
@@ -167,7 +172,8 @@ class KPathSetyawanCurtarolo(KPathBase):
         if not np.allclose(self._structure.lattice.matrix, self._prim.lattice.matrix, atol=atol):
             warn(
                 "The input structure does not match the expected standard primitive! "
-                "The path may be incorrect. Use at your own risk."
+                "The path may be incorrect. Use at your own risk.",
+                stacklevel=2,
             )
 
         lattice_type = self._sym.get_lattice_type()
@@ -181,7 +187,7 @@ class KPathSetyawanCurtarolo(KPathBase):
             elif "I" in spg_symbol:
                 self._kpath = self.bcc()
             else:
-                warn(f"Unexpected value for {spg_symbol=}")
+                warn(f"Unexpected value for {spg_symbol=}", stacklevel=2)
 
         elif lattice_type == "tetragonal":
             if "P" in spg_symbol:
@@ -194,7 +200,7 @@ class KPathSetyawanCurtarolo(KPathBase):
                 else:
                     self._kpath = self.bctet2(c, a)
             else:
-                warn(f"Unexpected value for {spg_symbol=}")
+                warn(f"Unexpected value for {spg_symbol=}", stacklevel=2)
 
         elif lattice_type == "orthorhombic":
             a = self._conv.lattice.abc[0]
@@ -218,7 +224,7 @@ class KPathSetyawanCurtarolo(KPathBase):
             elif "C" in spg_symbol or "A" in spg_symbol:
                 self._kpath = self.orcc(a, b, c)
             else:
-                warn(f"Unexpected value for {spg_symbol=}")
+                warn(f"Unexpected value for {spg_symbol=}", stacklevel=2)
 
         elif lattice_type == "hexagonal":
             self._kpath = self.hex()
@@ -252,7 +258,7 @@ class KPathSetyawanCurtarolo(KPathBase):
                     if b * cos(alpha * pi / 180) / c + b**2 * sin(alpha * pi / 180) ** 2 / a**2 > 1:
                         self._kpath = self.mclc5(a, b, c, alpha * pi / 180)
             else:
-                warn(f"Unexpected value for {spg_symbol=}")
+                warn(f"Unexpected value for {spg_symbol=}", stacklevel=2)
 
         elif lattice_type == "triclinic":
             kalpha = self._rec_lattice.parameters[3]
@@ -268,7 +274,7 @@ class KPathSetyawanCurtarolo(KPathBase):
                 self._kpath = self.trib()
 
         else:
-            warn(f"Unknown lattice type {lattice_type}")
+            warn(f"Unknown lattice type {lattice_type}", stacklevel=2)
 
     @property
     def conventional(self):
@@ -603,7 +609,7 @@ class KPathSetyawanCurtarolo(KPathBase):
     def rhl2(self, alpha):
         """RHL2 Path."""
         self.name = "RHL2"
-        eta = 1 / (2 * tan(alpha / 2.0) ** 2)
+        eta = 1 / (2 * math.tan(alpha / 2.0) ** 2)
         nu = 3 / 4 - eta / 2.0
         kpoints = {
             "\\Gamma": np.array([0.0, 0.0, 0.0]),
@@ -908,7 +914,7 @@ class KPathSeek(KPathBase):
         site_data: list[Composition] = species
 
         if not system_is_tri:
-            warn("Non-zero 'magmom' data will be used to define unique atoms in the cell.")
+            warn("Non-zero 'magmom' data will be used to define unique atoms in the cell.", stacklevel=2)
             site_data = zip(species, [tuple(vec) for vec in sp["magmom"]], strict=True)  # type: ignore[assignment]
 
         unique_species: list[SpeciesLike] = []
@@ -1068,7 +1074,8 @@ class KPathLatimerMunro(KPathBase):
             print("reducible")
             warn(
                 "The unit cell of the input structure is not fully reduced!"
-                "The path may be incorrect. Use at your own risk."
+                "The path may be incorrect. Use at your own risk.",
+                stacklevel=2,
             )
 
         if magmom_axis is None:
@@ -1152,7 +1159,8 @@ class KPathLatimerMunro(KPathBase):
             if "magmom" in self._structure.site_properties:
                 warn(
                     "The parameter has_magmoms is False, but site_properties contains the key magmom."
-                    "This property will be removed and could result in different symmetry operations."
+                    "This property will be removed and could result in different symmetry operations.",
+                    stacklevel=2,
                 )
                 self._structure.remove_site_property("magmom")
             sga = SpacegroupAnalyzer(self._structure)
@@ -1387,7 +1395,7 @@ class KPathLatimerMunro(KPathBase):
         return point_orbits_in_path, line_orbits_in_path
 
     def _get_key_points(self):
-        decimals = ceil(-1 * np.log10(self._atol)) - 1
+        decimals = math.ceil(-1 * np.log10(self._atol)) - 1
         bz = self._rec_lattice.get_wigner_seitz_cell()
 
         key_points = []
@@ -1537,7 +1545,7 @@ class KPathLatimerMunro(KPathBase):
             to_pop = []
             p00 = key_points[l0[0]]
             p01 = key_points[l0[1]]
-            pmid0 = p00 + e / pi * (p01 - p00)
+            pmid0 = p00 + math.e / pi * (p01 - p00)
             for ind_key, l1 in key_lines_copy.items():
                 p10 = key_points[l1[0]]
                 p11 = key_points[l1[1]]
@@ -1555,7 +1563,7 @@ class KPathLatimerMunro(KPathBase):
                     equivptsperp = True
 
                 if equivptspar:
-                    pmid1 = p10 + e / pi * (p11 - p10)
+                    pmid1 = p10 + math.e / pi * (p11 - p10)
                     for op in self._rpg:
                         if not equivline:
                             p00pr = np.dot(op, p00)
@@ -1569,7 +1577,7 @@ class KPathLatimerMunro(KPathBase):
                                     equivline = True
 
                 elif equivptsperp:
-                    pmid1 = p11 + e / pi * (p10 - p11)
+                    pmid1 = p11 + math.e / pi * (p10 - p11)
                     for op in self._rpg:
                         if not equivline:
                             p00pr = np.dot(op, p00)
@@ -1633,7 +1641,8 @@ class KPathLatimerMunro(KPathBase):
         if "magmom" not in struct.site_properties:
             warn(
                 "The 'magmom' property is not set in the structure's site properties."
-                "All magnetic moments are being set to zero."
+                "All magnetic moments are being set to zero.",
+                stacklevel=2,
             )
             struct.add_site_property("magmom", [np.array([0, 0, 0]) for _ in range(len(struct))])
 
@@ -1653,7 +1662,10 @@ class KPathLatimerMunro(KPathBase):
                 new_magmoms.append(magmom * magmom_axis)
 
         if found_scalar and not axis_specified:
-            warn("At least one magmom had a scalar value and magmom_axis was not specified. Defaulted to z+ spinor.")
+            warn(
+                "At least one magmom had a scalar value and magmom_axis was not specified. Defaulted to z+ spinor.",
+                stacklevel=2,
+            )
 
         struct.remove_site_property("magmom")
         struct.add_site_property("magmom", new_magmoms)
@@ -1739,7 +1751,9 @@ class KPathLatimerMunro(KPathBase):
         if len(pos1) != len(pos2):
             return False
         for idx, p1 in enumerate(pos1):
-            if abs(p1 - pos2[idx]) > tolerance[idx] and abs(p1 - pos2[idx]) < 1 - tolerance[idx]:
+            if not math.isclose(p1, pos2[idx], abs_tol=tolerance[idx], rel_tol=0) and math.isclose(
+                p1, pos2[idx], abs_tol=1 - tolerance[idx], rel_tol=0
+            ):
                 return False
         return True
 
