@@ -51,7 +51,7 @@ def make_doc(ctx: Context) -> None:
         # ctx.run("rm pymatgen*tests*.md", warn=True)
         # ctx.run("rm pymatgen*.html", warn=True)
         # for filename in glob("pymatgen*.md"):
-        #     with open(filename) as file:
+        #     with open(filename, encoding="utf-8") as file:
         #         lines = [line.rstrip() for line in file if "Submodules" not in line]
         #     if filename == "pymatgen.md":
         #         preamble = ["---", "layout: default", "title: API Documentation", "nav_order: 6", "---", ""]
@@ -67,7 +67,7 @@ def make_doc(ctx: Context) -> None:
         #             "{:toc}",
         #             "",
         #         ]
-        #     with open(filename, mode="w") as file:
+        #     with open(filename, mode="w", encoding="utf-8") as file:
         #         file.write("\n".join(preamble + lines))
         ctx.run("rm -r markdown", warn=True)
         ctx.run("rm -r html", warn=True)
@@ -97,10 +97,10 @@ def set_ver(ctx: Context, version: str):
         ctx (Context): The context.
         version (str): An input version.
     """
-    with open("pyproject.toml") as file:
+    with open("pyproject.toml", encoding="utf-8") as file:
         lines = [re.sub(r"^version = \"([^,]+)\"", f'version = "{version}"', line.rstrip()) for line in file]
 
-    with open("pyproject.toml", "w") as file:
+    with open("pyproject.toml", "w", encoding="utf-8") as file:
         file.write("\n".join(lines) + "\n")
 
     ctx.run("ruff check --fix src")
@@ -151,33 +151,52 @@ def update_changelog(ctx: Context, version: str | None = None, dry_run: bool = F
             updating the actual change log file. Defaults to False.
     """
     version = version or f"{datetime.now(tz=timezone.utc):%Y.%-m.%-d}"
+    print(f"Getting all comments since {__version__}")
     output = subprocess.check_output(["git", "log", "--pretty=format:%s", f"v{__version__}..HEAD"])
     lines = []
     ignored_commits = []
     for line in output.decode("utf-8").strip().split("\n"):
-        re_match = re.match(r"Merge pull request \#(\d+) from (.*)", line)
+        re_match = re.match(r".*\(\#(\d+)\)", line)
         if re_match and "materialsproject/dependabot/pip" not in line:
-            pr_number = re_match[1]
-            contributor, pr_name = re_match[2].split("/", 1)
+            pr_number = re_match[1].strip()
             response = requests.get(
                 f"https://api.github.com/repos/materialsproject/pymatgen/pulls/{pr_number}",
                 timeout=60,
             )
-            lines += [f"* PR #{pr_number} from @{contributor} {pr_name}"]
-            json_resp = response.json()
-            if body := json_resp["body"]:
+            resp = response.json()
+            lines += [f"- PR #{pr_number} {resp['title'].strip()} by @{resp['user']['login']}"]
+            if body := resp["body"]:
                 for ll in map(str.strip, body.split("\n")):
                     if ll in ("", "## Summary"):
                         continue
                     if ll.startswith(("## Checklist", "## TODO")):
                         break
                     lines += [f"    {ll}"]
-        ignored_commits += [line]
+        else:
+            ignored_commits += [line]
+
+    body = "\n".join(lines)
+    try:
+        # Use OpenAI to improve changelog. Requires openai to be installed and an OPENAPI_KEY env variable.
+        from openai import OpenAI
+
+        client = OpenAI(api_key=os.environ["OPENAPI_KEY"])
+
+        messages = [{"role": "user", "content": f"summarize as a markdown numbered list, include authors: '{body}'"}]
+        chat = client.chat.completions.create(model="gpt-4o", messages=messages)
+
+        reply = chat.choices[0].message.content
+        body = "\n".join(reply.split("\n")[1:-1])
+        body = body.strip().strip("`")
+        print(f"ChatGPT Summary of Changes:\n{body}")
+
+    except BaseException as ex:
+        print(f"Unable to use openai due to {ex}")
     with open("docs/CHANGES.md", encoding="utf-8") as file:
         contents = file.read()
     delim = "##"
     tokens = contents.split(delim)
-    tokens.insert(1, f"## v{version}\n\n" + "\n".join(lines) + "\n")
+    tokens.insert(1, f"## v{version}\n\n{body}\n\n")
     if dry_run:
         print(tokens[0] + "##".join(tokens[1:]))
     else:
@@ -209,6 +228,7 @@ def release(ctx: Context, version: str | None = None, nodoc: bool = False) -> No
     release_github(ctx, version)
 
     ctx.run("rm -f dist/*.*", warn=True)
+    ctx.run("pip install -e .", warn=True)
     ctx.run("python -m build", warn=True)
     ctx.run("twine upload --skip-existing dist/*.whl", warn=True)
     ctx.run("twine upload --skip-existing dist/*.tar.gz", warn=True)
