@@ -64,7 +64,7 @@ class TestTransformedStructure(PymatgenTest):
         assert isinstance(deepcopy(self.trans), TransformedStructure)
 
     def test_from_dict(self):
-        with open(f"{TEST_DIR}/transformations.json") as file:
+        with open(f"{TEST_DIR}/transformations.json", encoding="utf-8") as file:
             dct = json.load(file)
         dct["other_parameters"] = {"tags": ["test"]}
         t_struct = TransformedStructure.from_dict(dct)
