@@ -16,19 +16,19 @@ class TestBVAnalyzer(PymatgenTest):
 
     def test_get_valences(self):
         struct = Structure.from_file(f"{TEST_DIR}/LiMn2O4.json")
-        ans = [1, 1, 3, 3, 4, 4, -2, -2, -2, -2, -2, -2, -2, -2]
-        assert self.analyzer.get_valences(struct) == ans
+        valences = [1, 1, 3, 3, 4, 4, -2, -2, -2, -2, -2, -2, -2, -2]
+        assert self.analyzer.get_valences(struct) == valences
         struct = self.get_structure("LiFePO4")
-        ans = [1] * 4 + [2] * 4 + [5] * 4 + [-2] * 16
-        assert self.analyzer.get_valences(struct) == ans
+        valences = [1] * 4 + [2] * 4 + [5] * 4 + [-2] * 16
+        assert self.analyzer.get_valences(struct) == valences
         struct = self.get_structure("Li3V2(PO4)3")
-        ans = [1] * 6 + [3] * 4 + [5] * 6 + [-2] * 24
-        assert self.analyzer.get_valences(struct) == ans
+        valences = [1] * 6 + [3] * 4 + [5] * 6 + [-2] * 24
+        assert self.analyzer.get_valences(struct) == valences
         struct = Structure.from_file(f"{TEST_DIR}/Li4Fe3Mn1(PO4)4.json")
-        ans = [1] * 4 + [2] * 4 + [5] * 4 + [-2] * 16
-        assert self.analyzer.get_valences(struct) == ans
+        valences = [1] * 4 + [2] * 4 + [5] * 4 + [-2] * 16
+        assert self.analyzer.get_valences(struct) == valences
         struct = self.get_structure("NaFePO4")
-        assert self.analyzer.get_valences(struct) == ans
+        assert self.analyzer.get_valences(struct) == valences
 
         # trigger ValueError Structure contains elements not in set of BV parameters
         with pytest.raises(
