@@ -646,7 +646,7 @@ class ReconstructionGeneratorTests(PymatgenTest):
         self.Fe = Structure.from_spacegroup("Im-3m", lattice, species, coords)
         self.Si = Structure.from_spacegroup("Fd-3m", Lattice.cubic(5.430500), ["Si"], [(0, 0, 0.5)])
 
-        with open(f"{PMG_CORE_DIR}/reconstructions_archive.json") as data_file:
+        with open(f"{PMG_CORE_DIR}/reconstructions_archive.json", encoding="utf-8") as data_file:
             self.rec_archive = json.load(data_file)
 
     def test_build_slab(self):
