@@ -2,9 +2,9 @@ from __future__ import annotations
 
 import copy
 import json
+import math
 import os
 from collections import defaultdict
-from math import sqrt
 from pathlib import Path
 from typing import TYPE_CHECKING
 from unittest import TestCase
@@ -42,6 +42,7 @@ if TYPE_CHECKING:
 PMG_ENTRIES_DIR = os.path.dirname(os.path.abspath(pymatgen.entries.__file__))
 
 
+@pytest.mark.filterwarnings("ignore:MaterialsProjectCompatibility is deprecated")
 class TestCorrectionSpecificity(TestCase):
     """Make sure corrections are only applied to GGA or GGA+U entries."""
 
@@ -112,9 +113,9 @@ class TestCorrectionSpecificity(TestCase):
 
         assert len(processed) == 2
 
-        assert self.entry1.correction != 0
-        assert self.entry2.correction != 0
-        assert self.entry3.correction == 0.0
+        assert self.entry1.correction != approx(0)
+        assert self.entry2.correction != approx(0)
+        assert self.entry3.correction == approx(0)
 
 
 # abstract Compatibility tests
@@ -202,6 +203,7 @@ def test_overlapping_adjustments():
     assert len(processed) == 0
 
 
+@pytest.mark.filterwarnings("ignore:MaterialsProjectCompatibility is deprecated")
 class TestMaterialsProjectCompatibility(TestCase):
     def setUp(self):
         self.entry1 = ComputedEntry(
@@ -592,6 +594,9 @@ class TestMaterialsProjectCompatibility(TestCase):
         assert len(entries) == 2
 
     def test_parallel_process_entries(self):
+        # TODO: get DeprecationWarning: This process (pid=xxxx) is multi-threaded,
+        # use of fork() may lead to deadlocks in the child.
+        # pid = os.fork()
         with pytest.raises(
             ValueError,
             match="Parallel processing is not possible with for 'inplace=True'",
@@ -1132,6 +1137,7 @@ class TestMaterialsProjectCompatibility2020(TestCase):
         assert entry.energy == approx(-1)
         assert self.gga_compat.process_entry(entry).energy == approx(-1)
 
+    @pytest.mark.filterwarnings("ignore:MaterialsProjectCompatibility is deprecated")
     def test_get_explanation_dict(self):
         compat = MaterialsProjectCompatibility(check_potcar_hash=False)
         entry = ComputedEntry(
@@ -1228,7 +1234,7 @@ class TestMaterialsProjectCompatibility2020(TestCase):
     def test_processing_entries_inplace(self):
         # load two entries in GGA_GGA_U_R2SCAN thermo type
         json_file = Path(f"{TEST_FILES_DIR}/entries/entries_thermo_type_GGA_GGA_U_R2SCAN.json")
-        with open(json_file) as file:
+        with open(json_file, encoding="utf-8") as file:
             entries = json.load(file, cls=MontyDecoder)
         # check whether the compatibility scheme can keep input entries unchanged
         entries_copy = copy.deepcopy(entries)
@@ -2178,9 +2184,9 @@ class TestMaterialsProjectAqueousCompatibility:
 
         compat.process_entries([h2o_entry_1, h2o_entry_2, h2_entry_1, h2_entry_2, o2_entry_1])
 
-        assert compat.o2_energy == -4.9276
-        assert compat.h2o_energy == -5.195
-        assert compat.h2o_adjustments == -0.234
+        assert compat.o2_energy == approx(-4.9276)
+        assert compat.h2o_energy == approx(-5.195)
+        assert compat.h2o_adjustments == approx(-0.234)
 
         # the corrections should preserve the difference in energy among H2O and H2 polymorphs
         assert h2o_entry_2.energy_per_atom == approx(h2o_entry_1.energy_per_atom + 4.195)
@@ -2479,10 +2485,10 @@ class TestCorrectionErrors2020Compatibility(TestCase):
 
     def test_errors(self):
         for entry, expected in (
-            (self.entry1, sqrt((2 * 0.0101) ** 2 + (3 * 0.002) ** 2)),
-            (self.entry2, sqrt((3 * 0.0101) ** 2 + (4 * 0.002) ** 2)),
+            (self.entry1, math.sqrt((2 * 0.0101) ** 2 + (3 * 0.002) ** 2)),
+            (self.entry2, math.sqrt((3 * 0.0101) ** 2 + (4 * 0.002) ** 2)),
             (self.entry_sulfide, 0.0093),
-            (self.entry_fluoride, sqrt((3 * 0.0026) ** 2 + 0.0101**2)),
+            (self.entry_fluoride, math.sqrt((3 * 0.0026) ** 2 + 0.0101**2)),
             (self.entry_hydride, 0.0013),
         ):
             corrected_entry = self.compat.process_entry(entry)
