@@ -122,7 +122,7 @@ class TestPackmolSet(PymatgenTest):
             ],
         )
         input_set.write_input(self.tmp_path)
-        with open(f"{self.tmp_path}/packmol.inp") as file:
+        with open(f"{self.tmp_path}/packmol.inp", encoding="utf-8") as file:
             input_string = file.read()
             assert "maxit 0" in input_string
             assert "nloop 0" in input_string
@@ -154,7 +154,7 @@ class TestPackmolSet(PymatgenTest):
             box=[0, 0, 0, 2, 2, 2],
         )
         pw.write_input(self.tmp_path)
-        with open(f"{self.tmp_path}/packmol.inp") as file:
+        with open(f"{self.tmp_path}/packmol.inp", encoding="utf-8") as file:
             input_string = file.read()
             assert "inside box 0 0 0 2 2 2" in input_string
         with pytest.raises(ValueError, match=ERR_MSG_173):
